############
##Purpose: Load Results from Matlab, turn into Chord plots, 
## currently only for emissions embedded in trade, but could also be for trade itself
## Question with trade is about what to scale with. CPI exporter or importer.
## 

## The file first loads country groupings and then creates two diagrams
## It does this by first creating the one for cbam effects and then for tax ones
## This is because we scale the tax diagram by the cbam results, such that
## equal changes have an equal size in the diagrams
############
rm(list=ls())

###Might need to adjust this path:
#setwd("C:/Users/khsomme/Dropbox/Climate_Konstantin_Erhan/code/replication")

### Based on replication package structure
results_folder <- "./data/results"
data_folder <- "./data"
output_folder <- "./Step3_plotting_output/output/circle_diagrams"

##############
library(R.matlab)
library(chorddiag)
library(tidyverse)
library(circlize)
library(ComplexHeatmap)

############

# Here now chose which data/results to use
elasticity <- "base"
data_base <- "wiod_eora"
choice_indices <- "eu_ets"
res_choice <- "q"

dir.create(output_folder,showWarnings = FALSE)
########################################
## First read in general data
#######################################
ref_indeces <- read.delim(paste0(data_folder,
                                 "/output_mat/output_mat_",
                                data_base,
                                "/indices/",
                                choice_indices,
                                "_indices.csv"),
                          sep = ",",
                          header = F) %>% 
  mutate(ETS = "ETS",
         index = as.character(V1),
         V1 = NULL) ### Country indicees in data
country_names <- read.delim(paste0(data_folder,
                                   "/output_mat/output_mat_",
                                  data_base,
                                  "/countries.csv"),
                            sep = ",",
                            header = F) %>% 
  rename(index = V1,
         iso3 = V2) %>% 
  mutate(index = as.character(index))
country_groups <- read.delim(paste0(data_folder,
                                    "/raw/country_mapping.txt"),
                             sep = ",") %>% 
  select(region,alpha.3)  ##For grouping countries


###################
## Start CBAM diagram
scenario <- "cbam"
#####################
#Read necessary data
res <- 
  readMat(paste0(
    results_folder,
    "/res_",
    elasticity,
    "_",
    data_base,
    "_",
    scenario,
    ".mat")) ##Results from Simulation

#########################
## Start preparing data
#########################
##### Calculate change in the variable(s) of interest
r <- res[[paste0("r.",res_choice)]]
d <- res$d
E0 <- d["E0",,][[1]] #Production emissions
TrE0 <- d["TE0",,][[1]] #transport emissions
Ehat <- r["Ehat",,][[1]] #Change in both
TrEhat <- r["That",,][[1]]
###
TotE0 <- E0+TrE0
TotE1 <- E0*Ehat+TrE0*TrEhat
TotEchange <- TotE1-TotE0

TotEchange_2_2 <- apply(TotEchange,c(1,2),sum)

diag(TotEchange_2_2) <- 0

TotEchange_2_2 <- as.data.frame(TotEchange_2_2)
####################
##Transform data for plot
# Create the country groupings
df_2_2_long <- pivot_longer(cbind(row.names(TotEchange_2_2),TotEchange_2_2),
                                 cols = -`row.names(TotEchange_2_2)`,
                                 names_to = "exporter") %>% 
  rename(importer = `row.names(TotEchange_2_2)`) %>% 
  mutate(exporter = substr(exporter,2,4)) %>% 
  left_join(ref_indeces,by = join_by(importer == index)) %>% 
  rename(ETS_imp = ETS) %>% 
  left_join(ref_indeces,by = join_by(exporter == index)) %>% 
  rename(ETS_exp = ETS) %>% 
  left_join(country_names,by = join_by(importer == index)) %>% 
  rename(iso3_imp = iso3) %>% 
  left_join(country_names,by = join_by(exporter == index)) %>% 
  rename(iso3_exp = iso3) %>% 
  left_join(country_groups,by = join_by(iso3_imp == alpha.3)) %>% 
  rename(group_imp = region) %>% 
  left_join(country_groups,by = join_by(iso3_exp == alpha.3)) %>% 
  rename(group_exp = region) %>% 
  mutate(ETS_exp = if_else(is.na(ETS_exp),"Non_ETS","ETS"),
         ETS_imp = if_else(is.na(ETS_imp),"Non_ETS","ETS"),
         group_imp = replace(group_imp,ETS_imp=="ETS","EEA-EFTA"),
         group_imp = replace(group_imp,group_imp=="Europe","RoE"),
         group_exp = replace(group_exp,ETS_exp=="ETS","EEA-EFTA"),
         group_exp = replace(group_exp,group_exp=="Europe","RoE"),
         group_imp = replace(group_imp,group_imp=="Oceania","Other"),
         group_imp = replace(group_imp,is.na(group_imp),"Other"),
         group_exp = replace(group_exp,group_exp=="Oceania","Other"),
         group_exp = replace(group_exp,is.na(group_exp),"Other"))
         
####################
###make the plot
###################
dfchange_plot <- df_2_2_long %>% 
  group_by(group_exp,group_imp) %>% 
  summarise(value=sum(value)) %>% 
  as.data.frame()# %>% 

circos.clear()

pdf(paste0(output_folder,
           "/change_E_trade_",
          res_choice,
          "_",
          elasticity,
          "_",
          data_base,
          "_",
          scenario,
          ".pdf")
    )
grid.col = structure(c("antiquewhite","cadetblue","darkgrey",
                       "darkmagenta","gold","gray8",1:6),
                     names = c(unique(dfchange_plot$group_exp),
                               unique(dfchange_plot$group_imp)))

#par(family="LM Roman 10", cex = 1)  ##Need to install font for this
print(chordDiagram(dfchange_plot,
                   directional = 1,
                   direction.type = c("diffHeight", "arrows"),
                   diffHeight = mm_h(10), 
                   target.prop.height = mm_h(8),
                   link.arr.type = "big.arrow", 
                   link.arr.length = 0.05,
                   col = ifelse(dfchange_plot$value > 0, "red", "green"),
                   grid.col = grid.col,
                   annotationTrack = c("name","grid","axis")))


lgd_points = Legend(at = c("Increase", "Decrease"), type = "points", 
                    legend_gp = gpar(col = c( "red", "green")), title_position = "topleft", 
                    title = "Change in traded emissions",
                    title_gp = gpar(fontsize = 12),#, fontface = "bold"),
                    labels_gp = gpar(fontsize = 12))

#pushViewport(viewport(gp = gpar(fontfamily = "LM Roman 10")))
draw(lgd_points, x = unit(5, "mm"), y = unit(5, "mm"), just = c("left", "bottom"))

if (scenario == "tax"){ 
  title(main = "Change in traded emissions - Tax scenario")
} else {
    title(main = "Change in traded emissions - Tax and border tax scenario")
  }


graphics.off()

## Now save the cbam df seperately to create the scaling afterwards:
df_cbam_change_plot <- dfchange_plot

###################################
##Now rerun the diagram for tax scenario, but scale results
scenario <- "tax"
#####################
#Read necessary data
res <- 
  readMat(paste0(
    results_folder,
    "/res_",
    elasticity,
    "_",
    data_base,
    "_",
    scenario,
    ".mat")) ##Results from Simulation

#########################
## Start preparing data
#########################
##### Calculate change in the variable(s) of interest
r <- res[[paste0("r.",res_choice)]]
d <- res$d
E0 <- d["E0",,][[1]] #Production emissions
TrE0 <- d["TE0",,][[1]] #transport emissions
Ehat <- r["Ehat",,][[1]] #Change in both
TrEhat <- r["That",,][[1]]
###
TotE0 <- E0+TrE0
TotE1 <- E0*Ehat+TrE0*TrEhat
TotEchange <- TotE1-TotE0

TotEchange_2_2 <- apply(TotEchange,c(1,2),sum)

diag(TotEchange_2_2) <- 0

TotEchange_2_2 <- as.data.frame(TotEchange_2_2)
####################
##Transform data for plot
# Create the country groupings
df_2_2_long <- pivot_longer(cbind(row.names(TotEchange_2_2),TotEchange_2_2),
                            cols = -`row.names(TotEchange_2_2)`,
                            names_to = "exporter") %>% 
  rename(importer = `row.names(TotEchange_2_2)`) %>% 
  mutate(exporter = substr(exporter,2,4)) %>% 
  left_join(ref_indeces,by = join_by(importer == index)) %>% 
  rename(ETS_imp = ETS) %>% 
  left_join(ref_indeces,by = join_by(exporter == index)) %>% 
  rename(ETS_exp = ETS) %>% 
  left_join(country_names,by = join_by(importer == index)) %>% 
  rename(iso3_imp = iso3) %>% 
  left_join(country_names,by = join_by(exporter == index)) %>% 
  rename(iso3_exp = iso3) %>% 
  left_join(country_groups,by = join_by(iso3_imp == alpha.3)) %>% 
  rename(group_imp = region) %>% 
  left_join(country_groups,by = join_by(iso3_exp == alpha.3)) %>% 
  rename(group_exp = region) %>% 
  mutate(ETS_exp = if_else(is.na(ETS_exp),"Non_ETS","ETS"),
         ETS_imp = if_else(is.na(ETS_imp),"Non_ETS","ETS"),
         group_imp = replace(group_imp,ETS_imp=="ETS","EEA-EFTA"),
         group_imp = replace(group_imp,group_imp=="Europe","RoE"),
         group_exp = replace(group_exp,ETS_exp=="ETS","EEA-EFTA"),
         group_exp = replace(group_exp,group_exp=="Europe","RoE"),
         group_imp = replace(group_imp,group_imp=="Oceania","Other"),
         group_imp = replace(group_imp,is.na(group_imp),"Other"),
         group_exp = replace(group_exp,group_exp=="Oceania","Other"),
         group_exp = replace(group_exp,is.na(group_exp),"Other"))

####################
###make the plot
###################
dfchange_plot <- df_2_2_long %>% 
  group_by(group_exp,group_imp) %>% 
  summarise(value=sum(value)) %>% 
  as.data.frame()# %>% 

circos.clear()

pdf(paste0(output_folder,
           "/change_E_trade_",
           res_choice,
           "_",
           elasticity,
           "_",
           data_base,
           "_",
           scenario,
           ".pdf")
)

grid.col = structure(c("antiquewhite","cadetblue","darkgrey",
                       "darkmagenta","gold","gray8",1:6),
                     names = c(unique(dfchange_plot$group_exp),
                               unique(dfchange_plot$group_imp)))

## Now calculate the scaling of the diagram (need to convert the difference
## into degrees)
scalar_trans <- (sum(abs(dfchange_plot$value))/
                   (sum(abs(df_cbam_change_plot$value))))*360/6
circos.par(gap.after = c("EU+" = scalar_trans))

#par(family="LM Roman 10", cex = 1.3)

print(chordDiagram(dfchange_plot,
                   directional = 1,
                   direction.type = c("diffHeight", "arrows"),
                   diffHeight = mm_h(10), 
                   target.prop.height = mm_h(8),
                   link.arr.type = "big.arrow", 
                   link.arr.length = 0.05,
                   col = ifelse(dfchange_plot$value > 0, "red", "green"),
                   grid.col = grid.col,
                   annotationTrack = c("name","grid","axis")))

lgd_points = Legend(at = c("Increase", "Decrease"), type = "points", 
                    legend_gp = gpar(col = c( "red", "green")), title_position = "topleft", 
                    title = "Change in traded emissions",
                    title_gp = gpar(fontsize = 12),#, fontface = "bold"),
                    labels_gp = gpar(fontsize = 12))

#pushViewport(viewport(gp = gpar(fontfamily = "LM Roman 10")))
draw(lgd_points, x = unit(5, "mm"), y = unit(5, "mm"), just = c("left", "bottom"))

if (scenario == "tax"){ 
  title(main = "Change in traded emissions - Tax scenario")
} else {
  title(main = "Change in traded emissions - Tax and border tax scenario")
}


graphics.off()
