********************
* Read in Matlab output and turn into map 
********************
clear
********************
** All you have to adjust is the folder structure. Chose where the CSVs are saved 
* and where you would like to have them exported to.
* This file only saves CSVs, but the maps can easily be made in Stata
* The maps in the paper, however, are produced by a cartographic unit within 
* the World Bank
********************
//To chose:
* Folder structure. Adapt to your setting.
global personal_path "C:\Users\wb614536\OneDrive - WBG\Documents\Reproducibility\20231205-outsourcing-environment-v2\replication\replication"
***These ones are adjusted to the replication package structure
global data_path "${personal_path}\data"
global results_path "${personal_path}\data\results_csv"
global intermediate "${personal_path}\Step3_plotting_output\intermediate"
global output "${personal_path}\Step3_plotting_output\output\maps"
**************

sysdir set PLUS "${personal_path}\Step3_plotting_output\ado\"

********************
** From here on it just runs and creates on csv per loop in the end
foreach simulation_type in "tax" "cbam"{
	
foreach initial_type in "q" "p"{ 
	
foreach elasticity_type in "base" {  // Can add "fl" here
		
* Data base
global data_type "wiod_eora"
* elasticity
global elasticity `elasticity_type'

* simulation 
global simulation `simulation_type'

* Index (linked to simulation)
global index "eu_ets_indices"
* Carbon producer setting
global initial `initial_type'

***************
global result "${elasticity}_${data_type}_${simulation}"
global results_csv "${results_path}\res_${result}"
global shares "${data_path}\output_mat\output_mat_${data_type}"

**************
//Read in the country names
clear
import delimited "$shares\countries.csv"
rename v1 index
rename v2 WB_A3

local country_number = _N  //For loop later on 

cd "$intermediate"
save countries, replace

**************
//Read in the data that we want to include 
clear
import delimited "$shares\indices\\${index}.csv"
rename v1 index

merge m:1 index using countries
keep if _merge==3
drop _merge
gen index_country=1

cd "$intermediate"
save index, replace

** Production Emissions
clear
import delimited "$results_csv\\${initial}_Eprod.csv"

gen index = _n
merge 1:1 index using countries, nogen

gen Eprod_percentage=(v1-1)*100
format Eprod_percentage %9.2f
rename v1 Eprod

save "$intermediate\\${initial}_Eprod", replace

** Total Emissions
clear
import delimited "$results_csv\\${initial}_Etot.csv"

gen index = _n
merge 1:1 index using countries, nogen

gen Etot_percentage=(v1-1)*100
format Etot_percentage %9.2f
rename v1 Etot

save "$intermediate\\${initial}_Etot", replace


** Output
clear
import delimited "$results_csv\\${initial}_Ytot.csv"

gen index = _n
merge 1:1 index using countries, nogen

gen Ytot_percentage=(v1-1)*100
format Ytot_percentage %9.2f
rename v1 Ytot

save "$intermediate\\${initial}_Ytot", replace

** Welfare
clear
import delimited "$results_csv\\${initial}_Welf.csv"

gen index = _n
merge 1:1 index using countries, nogen

gen Welf_percentage=(v1-1)*100
format Welf_percentage %9.2f
rename v1 Welf
*/
save "$intermediate\\${initial}_Welf", replace

** Export
clear
import delimited "$results_csv\\${initial}_Exphat.csv"

gen index = _n
merge 1:1 index using countries, nogen

gen Exp_percentage=(v1-1)*100
format Exp_percentage %9.2f
rename v1 Exp

save "$intermediate\\${initial}_Exphat", replace

** Wage Income
clear
import delimited "$results_csv\\${initial}_Wageincome.csv"

gen index = _n
merge 1:1 index using countries, nogen

gen Wageincome_percentage=(v1-1)*100
format Wageincome_percentage %9.2f
rename v1 Income

save "$intermediate\\${initial}_Wageincome", replace

** Leakage
clear
import delimited "$results_csv\\${initial}_Leak.csv"

gen index = _n
merge 1:1 index using countries, nogen

gen Leak_percentage=(v1)*100
format Leak_percentage %9.2f
drop v1

save "$intermediate\\${initial}_Leak", replace

** Outsourcing
clear
import delimited "$results_csv\\${initial}_Outsrc.csv"

gen index = _n
merge 1:1 index using countries, nogen

gen Outsrc_percentage=(v1-1)*100
format Outsrc_percentage %9.2f

rename v1 Outsourcing
format Outsourcing %9.2f

save "$intermediate\\${initial}_Outsrc", replace

** Outsourcing fixed Y
clear
import delimited "$results_csv\\${initial}_Outsrc_fixY.csv"

gen index = _n
merge 1:1 index using countries, nogen

gen Outsrc_fixY_percentage=(v1-1)*100
format Outsrc_fixY_percentage %9.2f

rename v1 Outsourcing_fixY
format Outsourcing_fixY %9.2f

save "$intermediate\\${initial}_Outsrc_fixY", replace

** Outsourcing fixed Y PP
clear
import delimited "$results_csv\\${initial}_Outsrc_fixY_pp.csv"

gen index = _n
merge 1:1 index using countries, nogen

gen Outsrc_fixY_pp_percentage=(v1-1)*100
format Outsrc_fixY_pp_percentage %9.2f

rename v1 Outsourcing_fixY_pp
format Outsourcing_fixY_pp %9.4f

save "$intermediate\\${initial}_Outsrc_fixY_pp", replace


** Emission input fixed Y
clear
import delimited "$results_csv\\${initial}_E_input_fixY.csv"

gen index = _n
merge 1:1 index using countries, nogen

gen E_input_fixY_percentage=(v1-1)*100
format E_input_fixY_percentage %9.2f

rename v1 E_input_fixY
format E_input_fixY %9.2f

save "$intermediate\\${initial}_E_input_fixY", replace

** Abatement
clear
import delimited "$results_csv\\${initial}_Abatement.csv"

gen index = _n
merge 1:1 index using countries, nogen

gen Abatement_percentage=(v1-1)*100
format Abatement_percentage %9.2f

rename v1 Abatement
format Abatement %9.2f

save "$intermediate\\${initial}_Abatement", replace

** Abatement fixed Y
clear
import delimited "$results_csv\\${initial}_Abatement_fixY.csv"

gen index = _n
merge 1:1 index using countries, nogen

gen Abatement_fixY_percentage=(v1-1)*100
format Abatement_fixY_percentage %9.2f

rename v1 Abatement_fixY
format Abatement_fixY %9.2f

save "$intermediate\\${initial}_Abatement_fixY", replace


*********************
*** Starting values

** Output
clear
import delimited "$results_csv\Ytot0.csv"

gen index = _n
merge 1:1 index using countries, nogen
rename v1 Ytot0

save "$intermediate\Ytot0", replace

** Emissions
clear
import delimited "$results_csv\Etot0.csv"

gen index = _n
merge 1:1 index using countries, nogen
rename v1 Etot0

save "$intermediate\Etot0", replace


*********************
** Descriptives

** Initial tax rates
clear
import delimited "$shares\psi\psi.csv"
egen mean_var=rowmean(v*)
rename mean_var psi
keep psi
gen index = _n
merge 1:1 index using countries, nogen

merge 1:1 WB_A3 using index, nogen
gen help=psi 
egen psi_simulation = max(help/index_country), by(index_country)
replace psi_simulation = psi if index_country==.


drop help index_country

format psi psi_simulation %9.2f

save "$intermediate\psi", replace
*********************
//Now use the world data set, merge the variable of interest and plot
clear 

use "${data_path}\raw\world"
//keep WB_A3
cd "$intermediate"
//drop if WB_A3=="-99" // Weird countries
replace WB_A3 = "COD" if WB_A3=="ZAR" // Demoractic Republic of Congo
merge m:1 WB_A3 using ${initial}_Eprod, nogen
merge m:1 WB_A3 using ${initial}_Leak, nogen
merge m:1 WB_A3 using ${initial}_Wageincome, nogen
merge m:1 WB_A3 using psi, nogen
//merge m:1 WB_A3 using alpha, nogen
merge m:1 WB_A3 using ${initial}_Exphat, nogen
merge m:1 WB_A3 using ${initial}_Outsrc, nogen
merge m:1 WB_A3 using ${initial}_Abatement, nogen
merge m:1 WB_A3 using ${initial}_Outsrc_fixY, nogen
merge m:1 WB_A3 using ${initial}_Abatement_fixY, nogen
merge m:1 WB_A3 using ${initial}_Ytot, nogen
merge m:1 WB_A3 using ${initial}_Welf, nogen
merge m:1 WB_A3 using ${initial}_E_input_fixY, nogen
merge m:1 WB_A3 using ${initial}_Outsrc_fixY_pp, nogen

merge m:1 WB_A3 using Ytot0, nogen
merge m:1 WB_A3 using Etot0, nogen
 
gen Eintens0 = Etot0/Ytot0 *1000000
format Eintens0 %9.0f


gen ${initial}_Eintens = Eprod/Ytot
gen ${initial}_Eintens_percentage=(${initial}_Eintens-1)*100
format ${initial}_Eintens_percentage %9.2f

drop if ${initial}_Eintens==.


unab vlist : _all
sort `vlist'
quietly by `vlist':  gen dup = cond(_N==1,0,_n)
drop if dup>1

*/
***Initial psi
spmap psi using "$data_path\raw\world_shp_merc" , id(_ID) ///
	legstyle(2) legend(pos(7) size(3.8) region(fcolor(gs15)))   /// Legend design
	clnum(7)  /// clmethod(custom) clbreaks(-21 -10 -5 -1 0 3)
	title("Initial average tax rate", size(5)) ///
	note("$/t, unweighted sectoral average", size(3.5))
	
graph export "$output/psi.png", replace
*/


***Initial Eintens 
spmap Eintens0 using  "$data_path\raw\world_shp_merc", id(_ID) /// 
	legstyle(2) legend(pos(7) size(3.8) region(fcolor(gs15)))   /// Legend design
	 clnum(7) /// clnum(7)  /// clmethod(custom) clbreaks(-21 -10 -5 -1 0 3) ///  Legend entries clm(custom) clbreaks(-21(1)3) //
	/// //	ocolor(white ..) osize(0.05 ..)  /// Country boundary color and thickness
	title("Initital Emission intensity", size(5)) ///
	note("t of CO2eq./ Mil. Dollar of output", size(3.5))
	
graph export "$output/Eintens0.png", replace

di "baseline done"

***Emissionintensity (change) from production
spmap ${initial}_Eintens_percentage using  "$data_path\raw\world_shp_merc", id(_ID) /// 
	legstyle(2) legend(pos(7) size(3.8) region(fcolor(gs15)))   /// Legend design
	clnum(7)  /// clmethod(custom) clbreaks(-21 -10 -5 -1 0 3) ///  Legend entries clm(custom) clbreaks(-21(1)3) //
	/// //	ocolor(white ..) osize(0.05 ..)  /// Country boundary color and thickness
	title("Change in production emission intensity (in %)", size(5)) ///
	//note("Percentage change", size(2.5))
	
graph export "$output//${initial}_${simulation}_Eintens.png", replace
*/


***Welfare
spmap Welf_percentage using  "$data_path\raw\world_shp_merc", id(_ID) ///  
	legstyle(2) legend(pos(7) size(3.8) region(fcolor(gs15)))   /// Legend design
	clnum(7) ///  clmethod(custom) clbreaks(-27 -10 -5 -2 -1 0 2.5 5)  Legend entries clm(custom) clbreaks(-21(1)3) //
	/// //	ocolor(white ..) osize(0.05 ..)  /// Country boundary color and thickness
	title("Change in welfare (in %)", size(5)) ///
	//note("Percentage change", size(2.5))
	
graph export "$output//${initial}_${simulation}_Welf.png", replace



***Outsourcing fixed Y
spmap Outsrc_fixY_percentage using  "$data_path\raw\world_shp_merc", id(_ID) ///  
	legstyle(2) legend(pos(7) size(3.8) region(fcolor(gs15)))   /// Legend design
	clnum(7)  ///  clmethod(custom) clbreaks(-1 -0.2 -0.1 0 0.1 0.2 0.8)   /// clmethod(custom) clbreaks(-21 -10 -5 -1 0 3)  Legend entries clm(custom) clbreaks(-21(1)3) //
	/// //	ocolor(white ..) osize(0.05 ..)  /// Country boundary color and thickness
	title("Change in average share of M in production (in %)", size(5)) /// 
	note("Averages are output weighted, keeping output fixed", size(3.5))
	
graph export "$output//${initial}_${simulation}_Outsrc_fixY.png", replace


*/

***Abatement
spmap Abatement_fixY_percentage using  "$data_path\raw\world_shp_merc", id(_ID) ///  
	legstyle(2) legend(pos(7) size(3.8)  ) /// Legend design
	clnum(7)  ///
	title("Change in average share of L in production (in %)", size(5)) /// 
	note("Averages are output weighted, keeping output fixed", size(3.5))
	
graph export "$output//${initial}_${simulation}_Abatement_fixY.png", replace

***Wage income
spmap Wageincome_percentage using  "$data_path\raw\world_shp_merc", id(_ID) /// 
	legstyle(2) legend(pos(7) size(3.8) region(fcolor(gs15)))   /// Legend design
	clnum(7)   ///  
	title("Change in disposable income (in %)", size(5)) 
	
graph export "$output//${initial}_${simulation}_Income.png", replace

***Output
spmap Ytot_percentage using  "$data_path\raw\world_shp_merc", id(_ID) ///  
	legstyle(2) legend(pos(7) size(3.8) region(fcolor(gs15)))   /// Legend design
	clnum(7)  /// clmethod(custom) clbreaks(-21 -10 -5 -1 0 3)  Legend entries clm(custom) clbreaks(-21(1)3) //
	/// //	ocolor(white ..) osize(0.05 ..)  /// Country boundary color and thickness
	title("Change in total output (in %)", size(5)) 
	
graph export "$output/${initial}_${simulation}_Ytot.png", replace
*/

}
}
}