###############
##Purpose: Extract info from IO data for modelling
#I.e. get sector input shares etc.
#author: KS, 24.01.2023
#Run this scripts loads all the scripts that do actual preparation of data
###############

#rm(list=ls())

# ##Adjust to your file
# setwd("C:/Users/khsomme/OneDrive - UvA/PhD/Worldbank/transport/analysis/replication")
# 
# ##Read packages
# library(tidyverse)
# library(foreign) ## To read and write dta data
# library(janitor) ## For adding a row at bottom
# library(CoordinateCleaner)
# library(readxl) # Read Excel data
# library(xtable) # For making pretty summary tables
# 

#################
##Choices: (for replication no adjustments needed)
#################
#target_folder <- "data/output_mat/output_mat_wiod_eora" #Name of folder,
# in which results are saved
file_name <- "wiod_eora_5bn_other" #If you created other data in datamanipulation
# you can choose other ones here

########################
## If you want to play around with other options, you can additionally chose:
#######################
reference_country <- "USA"   #Only used for CPI
scope_2 <- FALSE  ##Want to use scope 2 instead of scope 1 emissions
psi_choice <- "oecd" #rff vs oecd   ##If you want to use tax rates based on RFF
#instead of based on OECD (see paper)

tau_threshold <- 1000 #If EU implied tax above this value: use OECD data instead ($/t)
##########
##Adjust names of saved files based on choices above
if (scope_2 ==TRUE) {
  target_folder <- paste(target_folder,"scope2",sep="_")
}

if (psi_choice == "rff") {
  target_folder <- paste(target_folder,"psi_rff",sep="_")
}

dir.create(paste("./data/","output_mat",sep=""), showWarnings = F)
dir.create(paste("./data/",target_folder,sep=""), showWarnings = F)
##################################
## Pre: Calculate tax rates based on Eurostat and OECD data
source("./datamanipulation_scripts/analysis/env_taxes.R")

###############################
##Start reading in prepared IO data and adjust to choices above
###############################
df_ag_NT <- readRDS(paste("./data/manipulated/IO/",
                          file_name,".rds",sep="")) %>% 
  select(-c(ends_with("cap_form"),ends_with("invent"))) #Main IO data, based on WIOD and EORA

if (scope_2 == TRUE) {
  df_ag_NT_E <- readRDS(paste("./data/manipulated/IO/",
                              file_name,"_scope2.rds",sep="")) %>% 
    select(-c(ends_with("cap_form"),ends_with("invent")))
} else {
  df_ag_NT_E <- readRDS(paste("./data/manipulated/IO/",
                              file_name,"_E.rds",sep="")) %>% 
    select(-c(ends_with("cap_form"),ends_with("invent"))) ##Also includes emissions data
}

df_ag_NT_E_T <- readRDS(paste("./data/manipulated/IO/",
                              file_name,"_E_T.rds",sep="")) %>% 
  select(-c(ends_with("cap_form"),ends_with("invent"))) #Also includes tax data


#Load a ll the sector setting from different script
source("./datamanipulation_scripts/manipulate/mappings/sector_mappings.R")

######### Load other data sets
eora_VA <- readRDS("./data/manipulated/IO/eora_aggregated_VA.rds")
suppressWarnings(cpi <- read.delim("./data/raw/FED/CPIAUCSL.csv",sep=",") %>% 
  mutate(year = as.numeric(substr(DATE,1,4)),
         CPIAUCSL_NBD20090101 = as.numeric(CPIAUCSL_NBD20090101)))


###### Needed for some operations
df_countries_in_df <- unique(df_ag_NT$Country)
#####################
## Now start the analysis
#####################
## trade matrices
source("./datamanipulation_scripts/analysis/prep_shares_ind/trade_matrices.R")

## Wage (w*L)
source("./datamanipulation_scripts/analysis/prep_shares_ind/wL.R")

##Alphas 
source("./datamanipulation_scripts/analysis/prep_shares_ind/alpha.R") ##Needed for other datamanipulation_scripts below

##Psi
source("./datamanipulation_scripts/analysis/prep_shares_ind/Psi.R")

##Epsilon
source("./datamanipulation_scripts/analysis/prep_shares_ind/epsilon.R") 

##Beta
source("./datamanipulation_scripts/analysis/prep_shares_ind/beta.R") 

##Gamma
source("./datamanipulation_scripts/analysis/prep_shares_ind/gamma.R") 

##Emissions
source("./datamanipulation_scripts/analysis/prep_shares_ind/Emissions.R") 

##Vartheta
source("./datamanipulation_scripts/analysis/prep_shares_ind/Vartheta.R") 

##SCC
source("./datamanipulation_scripts/analysis/prep_shares_ind/scc.R") 

##Transport emissions
source("./datamanipulation_scripts/analysis/prep_shares_ind/transport_emissions.R") 

##GDP
source("./datamanipulation_scripts/analysis/prep_shares_ind/gdp.R") 


#################################
## Add folder with country indices
#################################
dir.create(paste("./data/",target_folder,"/indices",sep=""), showWarnings = F)
source("./datamanipulation_scripts/manipulate/mappings/country_groupings.R")
for (group in unique(country_groupings$Region)) {
  df <- country_groupings %>% filter(Region == group)
  ref_indeces <- select(filter(df_countries,
                               Country %in% df$Country),
                        id)
  write.table(ref_indeces, paste("./data/",
                              target_folder,
                              "/indices/",
                              group,
                              "_indices.csv",
                              sep=""),
              sep=",",
              row.names=FALSE, col.names = FALSE)
}

####################################
###Summary Table
source("./datamanipulation_scripts/analysis/summary_table.R") 
