dir.create(paste("./data/",target_folder,"/vartheta",sep=""), showWarnings = F)
#################################
#Vartheta
#################################
### Take IO data with tax revenue at bottom
### Create GDP, by summing all VA in a country together
### Divide this by tax revenue in country
if (psi_choice == "oecd"){
  df_vartheta <- df_ag_NT_E_T %>% 
    filter(sup_sector_harm == "VA"| sup_sector_harm == "ENE_CC_tax_rev") %>% 
    mutate(Country = NULL) %>% 
    pivot_longer(-c(sup_sector_harm),names_to = "country_sector",
                 values_to = "Value") %>% 
    mutate(use_country = substr(country_sector,1,3),
           use_sector = substr(country_sector,5,nchar(country_sector))) %>% 
    pivot_wider(id_cols = c(use_country,use_sector),
                names_from = sup_sector_harm,
                values_from = Value) %>% 
    group_by(use_country) %>% 
    summarise(GDP = sum(VA,na.rm = T),
              tax_rev = mean(ENE_CC_tax_rev,na.rm = T)) %>%  ###Careful: tax revenue 
    #same in whole economy, not sector spec
    mutate(vartheta = tax_rev/GDP)
  
  ##Set NAs to 0 in concordance with psi above
  sum_vartheta <- summary(df_vartheta$vartheta)
  mean_vartheta <- sum_vartheta["Mean"]
  df_vartheta <- df_vartheta %>% 
    mutate(vartheta = replace(vartheta,
                              is.na(tax_rev),
                              0))
  
  write.table(select(df_vartheta,vartheta),
              paste("./data/",target_folder,"/vartheta/vartheta.csv",sep=""),
              sep=",",
              row.names=FALSE, col.names = FALSE)
} else if(psi_choice == "rff"){
  ### Multiply psi times total CO2 in a country
  ### Calculate GDP as sum of VAs
  ### Divide one by the other
  df_vartheta <- df_ag_NT_E %>% 
    filter(sup_sector_harm %in% c("VA","CO2")) %>% 
    pivot_longer(-c(sup_sector_harm,Country),
                 names_to = "country_sector",
                 values_to = "Value") %>% 
    mutate(use_country = substr(country_sector,1,3),
           use_sector = substr(country_sector,5,nchar(country_sector))) %>% 
    pivot_wider(names_from = sup_sector_harm,
                values_from = Value) %>% 
    group_by(use_country) %>% 
    summarise(GDP = sum(VA,na.rm=T),
              emissions = sum(CO2,na.rm=T)) %>% 
    left_join(df_carb_price, by = c("use_country" = "Country")) %>% 
    mutate(tax_rev = emissions *psi*e_price , ##Def of tax rev and psi, see email to Erhan
           vartheta = tax_rev/GDP) %>% 
    arrange(use_country)
  
  write.table(select(df_vartheta,vartheta),
              paste("./data/",target_folder,"/vartheta/vartheta.csv",sep=""),
              sep=",",
              row.names=FALSE, col.names = FALSE)
}
