dir.create(paste("./data/",target_folder,"/alpha",sep=""), showWarnings = F)
#################################
#Alpha_jk^n
#################################
########
#Energy costs
########
new_row_energy <- readRDS(paste("./data/manipulated/IO/e_cost",
                                file_name,
                                ".rds",
                                sep="")) %>% 
  select(Country,sector,e_cost) 

new_row_energy <- new_row_energy %>% 
    pivot_wider(names_from = c(Country,sector),
                values_from = c(e_cost)) %>% 
    mutate(Country = "TOT",
           sup_sector_harm = "energy_cost") %>%
    relocate(c(Country,sup_sector_harm), .before= everything())

df_ag_NT_E <- bind_rows(df_ag_NT_E, new_row_energy)
#rm(new_row_energy)

######
## Now  aggregate all inputs into M, sum M and VA together,
## independent of energy or emissions choice
######
df_long <- df_ag_NT_E %>% 
  pivot_longer(!c(Country,sup_sector_harm),#,
               names_to = "country_sector",
               values_to = "Use") %>% 
  mutate(use_country = substr(country_sector,1,3),
         use_sector = substr(country_sector,5,nchar(country_sector))) %>% 
  select(-c(country_sector)) %>% 
  group_by(sup_sector_harm,use_country,use_sector) %>% 
  #Aggregate over all the supply/exporting countries (for VA and CO2, country= TOT)
  summarise(tot_use = sum(Use))

#Now need to only keep intermediates, CO2 and VA. 
df_alpha <- df_long %>% 
  filter(sup_sector_harm %in% trade_sectors |
           sup_sector_harm == "NT" |
           sup_sector_harm == "VA" |
           sup_sector_harm == "CO2" |
           sup_sector_harm == "energy_cost") %>% 
  #Sum intermediates into one sector
  mutate(sup_sector_harm = replace(sup_sector_harm,
                                   sup_sector_harm %in% trade_sectors |
                                     sup_sector_harm == "NT",
                                   "M")
  ) %>% 
  group_by(sup_sector_harm,use_country,use_sector) %>% 
  summarise(tot_use = sum(tot_use)) %>% 
  #sum VA and M (=GO) and derive alphas, pivot wider for this (easier)
  pivot_wider(names_from= sup_sector_harm,
              values_from = tot_use) %>% 
  filter(use_sector != "final_use")
#####
### Now derive alphas 
#####
df_alpha <- df_alpha %>% 
    mutate(imputed_GO = M+VA, 
           alpha_M = (M-energy_cost)/imputed_GO, ##Need to avoid double counting
           alpha_G = (VA)/imputed_GO,
           alpha_E = energy_cost/imputed_GO) 


##Now need to replace negative alpha_Ls and alpha_Es>1
min_non_negative_G <- min(df_alpha$alpha_G[df_alpha$alpha_G >= 0])
min_non_negative_M <- min(df_alpha$alpha_M[df_alpha$alpha_M >= 0])

df_alpha <- df_alpha %>% mutate(alpha_G = replace(alpha_G,
                                                  alpha_G<0,
                                                  min_non_negative_G),
                                alpha_M = replace(alpha_M,
                                                  alpha_M<0,
                                                  min_non_negative_M),
                                alpha_E = if_else(alpha_G==min_non_negative_G,
                                                  1-alpha_M-alpha_G,
                                                  alpha_E),
                                alpha_E = if_else(alpha_M==min_non_negative_M,
                                                  (1-alpha_M-alpha_G),
                                                  alpha_E))

#Now check if the alphas sum to 1  
df_alpha[round(rowSums(select(ungroup(df_alpha),alpha_M,alpha_E,alpha_G),na.rm=T),3)!=1,] #There should be none

saveRDS(df_alpha,"./data/manipulated/alpha_e.rds") #For use further below

########
#### Export 
###Now in a loop always take one country and extract that csv
########
i <- 1
for (country in unique(df_alpha$use_country)){
  df_alpha_ex <- df_alpha %>% 
    filter(use_country == country) %>% 
    ungroup %>% 
    select(c(alpha_M,alpha_G,alpha_E))
  
  
  write.table(df_alpha_ex,
              paste("./data/",target_folder,"/alpha/alpha_",i,".csv",sep = ""),
              sep=",",
              row.names=FALSE, col.names = FALSE)
  i = i+1
}


##Add overview for what is in columns and what is in the rows
df_rows <- df_alpha %>% 
  ungroup() %>% 
  select(use_sector) %>% 
  unique() %>% 
  tibble() %>% 
  mutate(id = row_number()) %>% 
  relocate( id, .before = use_sector)
write.table(df_rows, paste("./data/",target_folder,"/alpha/rows.csv",sep=""),
            sep=",",
            row.names=FALSE, col.names = FALSE)

df_columns <- colnames(df_alpha_ex)
write.table(df_columns, paste("./data/",target_folder,"/alpha/columns.csv",sep=""),
            sep=",",
            row.names=FALSE, col.names = FALSE)