dir.create(paste("./data/",target_folder,"/beta",sep=""), showWarnings = F)
#################################
#beta_jk^n
#################################
### Get imports into row dimensions,
### make a total column based on all inputs into one sector-country
### Divide all inputs by it --> beta
df_beta <- df_ag_NT %>% 
  pivot_longer(!c(Country,sup_sector_harm),#,
               names_to = "country_sector",
               values_to = "Use") %>% 
  mutate(use_country = substr(country_sector,1,3),
         use_sector = substr(country_sector,5,nchar(country_sector))) %>% 
  select(-c(country_sector)) %>% 
  group_by(sup_sector_harm,use_country,use_sector) %>% 
  #Aggregate over all the supply/exporting countries
  summarise(tot_use = sum(Use)) %>% 
  filter(sup_sector_harm %in% trade_sectors |
           sup_sector_harm == "NT") %>% 
  group_by(use_country,use_sector) %>% 
  mutate(tot_int_input = sum(tot_use)) %>% 
  mutate(beta = tot_use/tot_int_input)

#### 
#Now check if the betas sum to 1 
#### 
# sum(filter(df_beta,
#            use_country=="LVA",
#            use_sector=="C26-C28",
#            sup_sector_harm %in% trade_sectors |
#              sup_sector_harm == "NT")$beta)

#### 
##Prepare for output
#### 
df_beta_ex <- df_beta %>% 
  filter(sup_sector_harm %in% trade_sectors |
           sup_sector_harm == "NT",
         use_sector != "final_use") %>% 
  select(-c(tot_int_input,tot_use)) %>% 
  pivot_wider(names_from = c(sup_sector_harm), values_from = beta) 


#### 
#### Export 
###Now in a loop always take one country and extract that csv
#### 
i <- 1
for (country in unique(df_beta_ex$use_country)){
  df_beta <- df_beta_ex %>% 
    filter(use_country == country) %>% 
    ungroup %>% 
    select(-c(use_country,use_sector))
  
  
  write.table(df_beta, paste("./data/",target_folder,"/beta/beta_",
                             i,
                             ".csv",
                             sep = ""),
              sep=",",
              row.names=FALSE, col.names = FALSE)
  i = i+1
}

df_rows <- df_beta_ex %>% 
  ungroup() %>% 
  select(use_sector) %>% 
  unique() %>% 
  tibble() %>% 
  mutate(id = row_number()) %>% 
  relocate( id, .before = use_sector)
write.table(df_rows, paste("./data/",target_folder,"/beta/rows.csv",sep=""),
            sep=",",
            row.names=FALSE, col.names = FALSE)

df_columns <- df_beta_ex %>% 
  pivot_longer(!c(use_country,use_sector),#,
               names_to = "country_sector",
               values_to = "imports") %>% 
  ungroup() %>% 
  select(country_sector) %>% 
  unique() %>% 
  tibble() %>% 
  mutate(id = row_number()) %>% 
  relocate( id, .before = country_sector)
write.table(df_columns, paste("./data/",target_folder,"/beta/columns.csv",sep=""),
            sep=",",
            row.names=FALSE, col.names = FALSE)
