dir.create(paste("./data/",target_folder,"/trans_emi",sep=""), showWarnings = F)

#################################
#Add transport emissions from Christea
#################################
#Load a ll the mappings for Christea data from different script
source("./datamanipulation_scripts/manipulate/mappings/christea_mappings.R")
source("./datamanipulation_scripts/manipulate/mappings/neighboring_countries.R")
christea <- read.dta("./data/raw/christea_et_al/emissions_modal_data.dta")
df_country_coordinates <- CoordinateCleaner::countryref
inflater <- cpi[cpi$year==2004,"CPIAUCSL_NBD20090101"]/
  cpi[cpi$year==2009,"CPIAUCSL_NBD20090101"]

##Values and weights
christea_wv <- read.dta("./data/raw/christea_et_al/wv_og.dta") %>% 
  #Inflation adjust
  mutate(inflated_value = vsum1/inflater,  #Now in 2009 dollar
         qsum1 = qsum1/10) %>%  #Turn into tons
  select(-description_gsc,vsum1,qsum1,inflated_value) %>% 
  rename(gsc = gsc_29)

##Add weight to value ratio and our sector classification
christea <- christea %>% 
  left_join(christea_wv) %>% 
  mutate(j = sector_mapping[description_gsc])

##Aggregate to our sector level
christea_j <- christea %>% 
  group_by(origin,destination,j) %>% 
  summarise(across(where(is.numeric),sum)) %>% 
  mutate(weight_val_ratio = qsum1/inflated_value)

################
##Now deal with the region to countries split
df_ind <- data.frame(origin=names(ind_countries),
                     Country=ind_countries, row.names=NULL)

region_split <- oceania %>% 
  rbind(C_C_Amer) %>% 
  rbind(E_Asia) %>% 
  rbind(EU27) %>% 
  rbind(Mala_Indo) %>% 
  rbind(Oth_Europe) %>% 
  rbind(Oth_CEE_CIS) %>% 
  rbind(MEAS_NAfr) %>% 
  rbind(S_o_Amer) %>% 
  rbind(R_SE_Asia) %>% 
  rbind(R_S_Asia) %>% 
  rbind(S_S_AFR) %>% 
  rbind(df_ind) %>% 
  rbind(CHIHKG)

region_split[duplicated(region_split$Country),]

rm(C_C_Amer,E_Asia,EU27,Mala_Indo,Oth_Europe,Oth_CEE_CIS,
   MEAS_NAfr,S_o_Amer,R_SE_Asia,R_S_Asia,S_S_AFR,ind_countries,CHIHKG)

join_christea <- christea_j %>% 
  full_join(region_split,
            relationship = "many-to-many") %>% 
  ungroup()

## First exporter (above) now importer
region_split_import <- region_split %>% 
  rename(use_country = Country,
         destination = origin)

df_christea <- join_christea %>% 
  full_join(region_split_import,
            relationship = "many-to-many") 

##########
#### Find duplicates and nas
# check <- df_christea[df_christea %>%
#                        ungroup() %>% 
#                        select(Country, use_country,j) %>%
#                        duplicated(),]
# 
# df_christea_na <- df_christea %>%
#  filter(is.na(Country) |
#            is.na(use_country))
#check <- distinct(select(df_christea,destination,use_country) %>% 
#                    filter(use_country %in% df_countries$Country))
##########
#Drop NAs (only two weird Russia observations)
df_christea <- df_christea %>% 
  filter(!is.na(Country),
         !is.na(use_country)) %>% 
  select(Country,use_country,j,qsh_sea,qsh_air,qsh_rail,
         qsh_road,weight_val_ratio)


###Replace mode shares and weight to value for intra country trade
variables <- c("qsh_sea","qsh_air","qsh_rail",
               "qsh_road")
###Intra-country mode shares (takes very long, maybe make with apply?)
for (var in variables){
  for (sector in unique(df_christea$j)){
    for (j in names(neighboring_countries)) {
      # extract neighboring countries
      neighbors <- neighboring_countries[[j]]
      # calculate mean value for neighboring countries
      mean_value <- mean(
        df_christea[[var]] [df_christea$Country==j & 
                              df_christea$use_country %in% neighbors & 
                              df_christea$j==sector],
        na.rm=T)
      # replace the zero value with mean
      df_christea[[var]] [df_christea$Country == j &
                            df_christea$use_country == j & 
                            df_christea$j==sector] <- mean_value
    }
  }
}

#####
#Load other needed data sources

#Land distances
suppressWarnings(land_dist <- read_xls("./data/raw/trade_boundaries_rep/data/dist_cepii/dist_cepii.xls") %>% 
                   rename(Country = iso_o,
                          use_country = iso_d) %>% 
                   select(Country,use_country,distw) %>% 
                   mutate(distw = as.numeric(distw)))  #in km
#Sea distances
sea_dist <- read_xlsx("./data/raw/trade_boundaries_rep/data/CERDI-seadistance_V1.1.xlsx") %>% 
  rename(Country = iso1,
         use_country =iso2) %>% 
  select(Country,use_country,seadistance)
#Merge the two and create within country seadistance
distance <- left_join(land_dist,sea_dist) %>% 
  mutate(seadistance = if_else(Country == use_country,
                               distw*1.96,
                               seadistance))  ##In km
rm(land_dist,sea_dist)

##Shapiro emissions
df_emissions_mode <- data.frame(sea_emi=9.53,air_emi=985.97,
                                rail_emi=23.0,road_emi=119.0) ## All per gCO2/ton-km
#Turn into t/km
df_emissions_mode <- df_emissions_mode/1000000  # tCO2/ton-km
###Now merge everything

df_trans_emi <- df_christea %>% 
  select(Country,use_country,j,qsh_sea,qsh_air,qsh_rail,qsh_road,
         weight_val_ratio) %>% 
  left_join(distance) %>% 
  cbind(df_emissions_mode)

##########################################################
#Create the variable of interest in tons of CO2 per dollar
df_trans_emi <- df_trans_emi %>% 
  mutate(trans_emi_int = weight_val_ratio*(qsh_sea*sea_emi*seadistance+
                                             distw*(qsh_air*air_emi+
                                                      qsh_rail*rail_emi+
                                                      qsh_road*road_emi)))


missing_count <- df_countries_in_df[!(df_countries_in_df %in% df_christea$Country)]
#Only ROW
###########
# Pivot wider, and do this by each j. Save files in same loop, add Row
i <- 1

for (sector in unique(df_trans_emi$j)){
  
  df_run <- filter(df_trans_emi,j == sector)
  
  df_run_wide <- df_run %>% 
    ungroup() %>% 
    select(Country,use_country,trans_emi_int) %>% 
    filter(Country %in% df_countries_in_df,
           use_country %in% df_countries_in_df) %>% 
    ###Now add a ROW
    adorn_totals(name = "ROW", fill="ROW") %>%
    ### Adorn total sums all values together and following turns this into
    ### a mean
    mutate(across(where(is.numeric), 
                  ~ replace(., n(), .[n()]/(n()-1)))) %>%
    pivot_wider(id_cols = Country,
                names_from = use_country,
                values_from = trans_emi_int) %>% 
    pivot_longer(-Country,
                 names_to = "use_country",
                 values_to = "Value") %>% 
    group_by(Country) %>% 
    mutate(Value = 
             ifelse(is.na(Value),
                    mean(Value,na.rm = T),
                    Value)) %>% 
    ungroup() %>% 
    group_by(use_country) %>% 
    mutate(Value = 
             ifelse(is.na(Value),
                    mean(Value,na.rm = T),
                    Value)) %>% 
    ungroup() %>% 
    # Finalize
    arrange(Country,use_country) %>% 
    pivot_wider(id_cols = use_country,
                names_from = Country,
                values_from = Value) 
  
  write.table(select(df_run_wide,-use_country),
              paste("./data/",
                    target_folder,
                    "/trans_emi/trans_emi_int",
                    "_",
                    i,
                    ".csv",sep = ""),
              sep=",",
              row.names=FALSE, col.names = FALSE)
  
  i <- i+1
}
## Add transport emissions for NT sector: Set to 0
nt_trans_emi <- matrix(0,
                       nrow = dim(df_run_wide)[1],
                       ncol = dim(df_run_wide)[1])
write.table(nt_trans_emi,
            paste("./data/",target_folder,
                  "/trans_emi/trans_emi_int",
                  "_",
                  i,".csv",sep = ""),
            sep=",",
            row.names=FALSE, col.names = FALSE)