###############
##Purpose: Make pretty summary tables
###############
#################
##Start reading in prepared IO data and adjust to choices above (do again, due to changes above)
#################
########################
df_psi <- read.delim(paste("./data/",target_folder,
                                      "/psi/psi.csv",sep=""),
                                sep=",",
                     header=F,)
df_countries <- read.delim(paste("./data/",
                                 target_folder,
                                           "/countries.csv",sep=""),
                                     sep=",",
                           header=F,)
df_sectors <- read.delim(paste("./data/",
                               target_folder,
                                           "/sectors.csv",sep=""),
                         header=F,
                         sep=",") %>% 
  select(V2) %>% 
  rename(Sector = V2)
colnames(df_psi) <- df_sectors$Sector

alpha_names <- list.files(paste("./data/",
                                target_folder,
                              "/alpha",sep=""),
                        pattern="alpha_*",
                        full.names=T)
list_alpha <- lapply(alpha_names, read.delim, sep=",",header=F)
names(list_alpha) <- df_countries$V2

#Load all the sector setting from different script
source("./datamanipulation_scripts/manipulate/mappings/sector_mappings.R")
source("./datamanipulation_scripts/manipulate/mappings/country_groupings.R")

######################################
df_long <- df_ag_NT_E %>% 
  pivot_longer(!c(Country,sup_sector_harm),#,
               names_to = "country_sector",
               values_to = "Value") %>% 
  mutate(use_country = substr(country_sector,1,3),
         use_sector = substr(country_sector,5,nchar(country_sector)))

######
df_psi <- colMeans(df_psi) %>% 
  as.data.frame()
df_psi <- cbind(rownames(df_psi),df_psi)
rownames(df_psi) <- NULL
colnames(df_psi) <- c("Sector","Tax")
######
alpha.M <- lapply(list_alpha, function(df) df[[1]]) %>% 
  bind_rows() %>% 
  rowMeans() %>% 
  cbind(df_sectors) %>% 
  rename(alpha.M = '.')
alpha.L <- lapply(list_alpha, function(df) df[[2]]) %>% 
  bind_rows()%>% 
  rowMeans() %>% 
  cbind(df_sectors) %>% 
  rename(alpha.L = '.')
alpha.E <- lapply(list_alpha, function(df) df[[3]]) %>% 
  bind_rows()%>% 
  rowMeans() %>% 
  cbind(df_sectors) %>% 
  rename(alpha.E = '.')

#####
df_table_final <- df_long %>% 
  mutate(country_group = if_else(use_country %in% eu_ets,1,
                                 if_else(use_country %in% oecd_high_eu,2,3))) %>% 
  pivot_wider(names_from = sup_sector_harm,
              values_from = Value) %>% 
  group_by(use_sector) %>% 
  summarise(Emissions = sum(CO2,na.rm = T),
            VA = sum(VA,na.rm = T)) %>% 
  mutate(Emission.intensity = Emissions/VA*1000000,
         VA=NULL,
         Emissions = NULL) %>% 
  rename(Sector = use_sector) %>% 
  filter(Sector != "final_use") %>% 
  left_join(df_psi) %>% 
  left_join(alpha.M) %>% 
  left_join(alpha.L) %>% 
  left_join(alpha.E) %>% 
  mutate(Sector = sector_names_short[Sector])
dir.create("./data/output/tables",showWarnings = F)
print(xtable(df_table_final,
             caption = "Summary statistics by sector. Emission intensity 
             calculated as global emissions divided by global value added 
             (t/Mio dollars); emission tax and input cost shares are 
             (unweighted) country averages.",
             label = "tab:summary_stats"),
      file = "./data/output/tables/summary.tex",
      include.rownames=FALSE)
