###############
##Purpose:Reading in and adjusting IO EORA data
#author: KS, 03.02.2023
###############

#################
##Start reading in EORA data
#################

#Load a ll the sector setting from different script
source("./datamanipulation_scripts/manipulate/mappings/sector_mappings.R")

eora_Q <- read.delim(
 "./data/raw/EORA26_2009/Eora26_2009_bp_Q.txt",header = FALSE)

eora_labels_Q <- read.delim(
 "./data/raw/EORA26_2009/labels_Q.txt",header = FALSE)

eora_T <- read.delim(
  "./data/raw/EORA26_2009/Eora26_2009_bp_T.txt",header = FALSE)

eora_labels_T <- read.delim(
  "./data/raw/EORA26_2009/labels_T.txt",header = FALSE)

eora_VA <- read.delim(
  "./data/raw/EORA26_2009/Eora26_2009_bp_VA.txt",header = FALSE)
eora_labels_VA <- read.delim(
  "./data/raw/EORA26_2009/labels_VA.txt",header = FALSE)

eora_FD <- read.delim(
  "./data/raw/EORA26_2009/Eora26_2009_bp_FD.txt",header = FALSE)
eora_labels_FD <- read.delim(
  "./data/raw/EORA26_2009/labels_FD.txt",header = FALSE)


##Needed for whole script, as most datasets need this dimension
dic_eora_v <- setNames(eora_labels_NT,
                       array(unique(eora_labels_T$V4)))
##Start by assigning our sector classification
##Create a new column including the mapping of choice
##Creating column headers in labels file

eora_labels_T <- eora_labels_T %>%
  mutate(sup_sector_harm = dic_eora_v[V4]) %>% 
  mutate(colnames_T = paste(V2,sup_sector_harm,sep="_"))

#################
##Start manipulating. First main IO table
#################
##Aggregate to the new sector level and assign labels
colnames(eora_T) <- eora_labels_T$colnames_T
eora_new <- select(eora_labels_T,V2,sup_sector_harm) %>% 
  cbind(eora_T) %>% 
  pivot_longer(-c(V2,sup_sector_harm),
               names_to =  "country_sector",
               values_to = "Value") %>% 
  mutate(use_country = substr(country_sector,1,3),
         use_sector = substr(country_sector,5,nchar(country_sector))) %>% 
  rename(Country = V2) %>% 
  group_by(Country,sup_sector_harm,use_country,use_sector) %>% 
  summarise(Value = sum(Value)) %>% 
  pivot_wider(names_from = c(use_country,use_sector),
              values_from = Value) %>% 
  filter(Country != "ROW") %>% 
  select(-starts_with("ROW"))
###
#Check trade ratio on GDP
total_GDP <- eora_new %>% ungroup() %>% 
  filter(Country != "TOT") %>% 
  summarise(across(where(is.numeric), sum)) %>% 
  rowSums() 

diag_m <- eora_new %>% ungroup() %>% 
  filter(Country != "TOT") %>% 
  pivot_longer(-c(sup_sector_harm,Country),
               names_to = "country_sector",
               values_to = "Value") %>% 
  mutate(imp_country = substr(country_sector,1,3),
         sector = substr(country_sector,4,nchar(country_sector))) %>% 
  filter(imp_country==Country)

sum_diag <- diag_m %>% ungroup() %>% summarise(total = sum(Value))

(total_GDP - sum_diag)/total_GDP

###
saveRDS(eora_new,"./data/manipulated/IO/eora_aggregated.rds")
######################################
#VA
######################################
colnames(eora_VA) <- eora_labels_T$colnames_T
eora_VA <- cbind(select(eora_labels_VA,V2),eora_VA) %>% 
  pivot_longer(-c(V2),
               names_to =  "country_sector",
               values_to = "Value") %>% 
  mutate(use_country = substr(country_sector,1,3),
         use_sector = substr(country_sector,5,nchar(country_sector))) %>% 
  rename(sup_sector_harm = V2) %>% 
  group_by(sup_sector_harm,use_country,use_sector) %>% 
  summarise(Value = sum(Value)) %>% 
  pivot_wider(names_from = c(use_country,use_sector),
              values_from = Value) %>% 
  select(-starts_with("ROW"))

##To create one full eora file, with only VA added at bottom of script
eora_VA_merge <- eora_VA %>% 
  filter(sup_sector_harm == "Consumption of fixed capital K.1" |
           sup_sector_harm == "Compensation of employees D.1") %>% 
  mutate(sup_sector_harm = if_else(sup_sector_harm == 
                                     "Consumption of fixed capital K.1",
                                   "capital",
                                   "labor")
  ) %>% 
  pivot_longer(-c(sup_sector_harm),
               names_to =  "country_sector",
               values_to = "Value") %>% 
  mutate(use_country = substr(country_sector,1,3),
         use_sector = substr(country_sector,5,nchar(country_sector))) %>% 
  pivot_wider(id_cols = c(use_country,use_sector),
              names_from = sup_sector_harm,
              values_from = Value) %>% 
  mutate(VA = capital + labor,
         capital = NULL,
         labor = NULL) %>% 
  pivot_wider(names_from = c(use_country,use_sector),
               values_from = VA) %>% 
  mutate(sup_sector_harm = "VA", .before = everything())

saveRDS(eora_VA,"./data/manipulated/IO/eora_aggregated_VA.rds")

######################################
#Emissions
######################################
colnames(eora_Q) <- eora_labels_T$colnames_T
eora_Q <- cbind(eora_labels_Q[,1:2],eora_Q)  %>% 
  pivot_longer(-c(V1,V2),
               names_to =  "country_sector",
               values_to = "Value") %>% 
  mutate(use_country = substr(country_sector,1,3),
         use_sector = substr(country_sector,5,nchar(country_sector))) %>% 
  rename(GHG = V1,sup_sector_harm = V2) %>% 
  group_by(GHG,sup_sector_harm,use_country,use_sector) %>% 
  summarise(Value = sum(Value)) %>% 
  pivot_wider(names_from = c(use_country,use_sector),
              values_from = Value) %>% 
  select(-starts_with("ROW"))

#For full EORA file with only one emissions category
eora_emissions <- eora_Q %>% 
filter(GHG == "I-GHG-CO2 emissions (Gg)" | 
         GHG == "I-GHG-CH4 emissions (Gg)" | 
         GHG == "I-GHG-N2O emissions (Gg)") %>%  
  mutate(across(where(is.numeric), ~if_else(GHG == "I-GHG-CH4 emissions (Gg)", .*28,.)),
         across(where(is.numeric), ~if_else(GHG == "I-GHG-N2O emissions (Gg)", .*265,.))) %>% 
  janitor::adorn_totals(fill = "Total_CO2") %>%  #Sum them all together
  filter(GHG == "Total") %>% #And keep only the total
  ungroup() %>% 
  select(-GHG)  %>% 
  mutate(across(where(is.numeric),~ . /1000)) #Turn into million tonnes
  
saveRDS(eora_Q,"./data/manipulated/IO/eora_aggregated_Q.rds")
saveRDS(eora_emissions,"./data/manipulated/IO/eora_aggregated_co2.rds")

######################################
#Final Use
######################################
##Currently ONLY keeping final use, as nothing else needed. Can be adjusted
#Give the final use categories shorter labels
eora_labels_FD <- eora_labels_FD %>% 
  mutate(label = if_else(V4 == "Household final consumption P.3h",
                         "hh",
                         if_else(V4 == "Non-profit institutions serving households P.3n",
                                 "NGO",
                                 if_else(V4 == "Government final consumption P.3g",
                                         "gov",
                                         if_else(V4 =="Gross fixed capital formation P.51",
                                                 "cap_form",
                                                 if_else(V4 == "Changes in inventories P.52",
                                                         "invent",
                                                         "acquis"))))),
         col_label = paste(V2,label,sep="_")
         )

######
colnames(eora_FD) <- eora_labels_FD$col_label

eora_FD <- cbind(eora_labels_T$V2,eora_labels_T$sup_sector_harm,eora_FD) %>% 
  rename(Country = `eora_labels_T$V2`,
         sup_sector_harm = `eora_labels_T$sup_sector_harm`) 

eora_final_use <- eora_FD %>% pivot_longer(!c(Country,sup_sector_harm),
               names_to = "country_sector",
               values_to = "Value") %>% 
  mutate(use_country = substr(country_sector,1,3),
         use_sector = substr(country_sector,5,nchar(country_sector)),
         country_sector = NULL,
         final_use = if_else(use_sector %in% c("hh", "gov","NGO" ),
                             1,
                             0)
         ) %>% 
  filter(final_use == 1) %>% 
  group_by(Country,sup_sector_harm,use_country,final_use) %>% 
  summarise(Value=sum(Value)) %>% 
  mutate(country_final_use = paste(use_country,"final_use",sep = "_")) %>% 
  pivot_wider(id_cols = c(Country,sup_sector_harm),
              names_from = country_final_use,
              values_from = Value) %>% 
  filter(Country != "ROW") %>% 
  select(-starts_with("ROW"))

saveRDS(eora_final_use,"./data/manipulated/IO/eora_final_use.rds")
######################################
#Merge together 
######################################
eora_new_full <- eora_new %>% 
  left_join(eora_final_use) %>% 
  ungroup() %>% 
  add_row(eora_VA_merge) %>% 
  add_row(eora_emissions)

saveRDS(eora_new_full,"./data/manipulated/IO/eora_full.rds")

#####################################################
####Add OECD tax revenue
#####################################################
df_tax_rev <- read.table("./data/raw/OECD/env_tax_rev/ERTR_31012023222956399.csv",
                         sep = ",",
                         header = TRUE) %>% 
  tibble() %>% 
  mutate(Country = NULL,
         use_sector = "A") %>% 
  rename(use_country = 1,
         sup_sector_harm = VAR) %>% 
  filter(Variable == "Tax revenue, millions USD",
         Year == 2009,
         CAT == "TOT",
         DOM == "CC") %>% 
  select(use_country,Value,sup_sector_harm,use_sector)

###Replicate matrix and add a column for each sector.
##Needed for merging to IO table
df_tax_rev <- data.frame(df_tax_rev,
                         i=rep(1:(length(final_sectors)),
                               ea=NROW(df_tax_rev)))

for (i in 1:length(final_sectors)){
  df_tax_rev <- df_tax_rev %>% 
    mutate(use_sector = replace(use_sector,
                                i ==i,
                                final_sectors[i]))
}

eora_new_full_T <- eora_new_full %>% 
  pivot_longer(!c(Country,sup_sector_harm),
               names_to = "country_sector",
               values_to = "Value") %>% 
  mutate(use_country = substr(country_sector,1,3),
         use_sector = substr(country_sector,5,nchar(country_sector)),
         country_sector = NULL) %>% 
  add_row(select(df_tax_rev,-i)) %>% 
  filter(use_country %in% unique(eora_new$Country)) %>% 
  pivot_wider(names_from = c(use_country,use_sector),
              values_from = c(Value))

saveRDS(eora_new_full_T,"./data/manipulated/IO/eora_full_T.rds")