###############
##Purpose:Reading in and adjusting IO WIOD data
#Need to be put on same sectoral structure as EORA and emissions data
#author: KS, 19.01.2023
###############

#################
##Start reading in WIOD data and setting up
#################
load("./data/raw/WIOTS_in_R/WIOT2009_October16_ROW.RData")
#Load a ll the sector setting from different script
source("./datamanipulation_scripts/manipulate/mappings/sector_mappings.R")

### Now build dictionaries based on mappings
dic_wiot_smallest <- setNames(new_smallest,old)
dic_wiot_num_smallest <- setNames(new_smallest_num,old_num)
dic_emi_smallest <- setNames(new_emi_smallest,old_emi)

#### For saving files, based on choice of NT
if (trade_NT ==FALSE){
  ending <- "NT"
} else{
  ending <- "other"
}

#################
##Read in all the WIOD CO2 data
#################
filenames <- list.files("./data/raw/WIOTS_in_R/AIR",
                        pattern="*.xls",
                        full.names=TRUE)
country_names <- lapply(filenames,substr,start=27,stop=29)
suppressMessages(list_emissions <- lapply(filenames, read_xls, sheet="2009"))
names(list_emissions) <- country_names


for (i in 1:length(list_emissions)){
list_emissions[[i]] <- list_emissions[[i]] %>% 
  mutate(Country = (country_names[[i]][1]))
}

for (i in 1:length(list_emissions)){
  colnames(list_emissions[[i]])[1:2] <- c("IndustryName","IndustryCode")
}


#####################################################
####Start aggregating
#####################################################
##1.Create a new column including the mapping of choice
wiot <- wiot %>% 
  mutate(sup_sector_harm = dic_wiot_smallest[IndustryCode],
         sup_sector_harm = if_else(is.na(sup_sector_harm),
                                   IndustryCode,
                                   sup_sector_harm))

wiot <- wiot %>% 
  relocate(sup_sector_harm, .after = Country) %>% 
  select(-c(Year,RNr,IndustryDescription))

###
#Check trade ratio on GDP
total_GDP <- wiot %>% ungroup() %>% 
  filter(Country != "TOT") %>% 
  select(-TOT) %>% 
  summarise(across(where(is.numeric), sum)) %>% 
  rowSums() 

diag_m <- wiot %>% ungroup() %>% 
  filter(Country != "TOT") %>% 
  pivot_longer(-c(sup_sector_harm,Country,IndustryCode),
               names_to = "country_sector",
               values_to = "Value") %>% 
  mutate(imp_country = substr(country_sector,1,3),
         sector = substr(country_sector,4,nchar(country_sector))) %>% 
  filter(imp_country==Country)

sum_diag <- diag_m %>% ungroup() %>% summarise(total = sum(Value))

(total_GDP - sum_diag)/total_GDP

###

##Now need to aggregate rows 
wiot_ag_r <- wiot %>% 
  group_by(Country,sup_sector_harm) %>% 
  summarise_at(vars(-c(IndustryCode)),
               sum)

#Rough check, should be roughly row number of new df:
#dim(wiot)[1]*length(unique(new_smallest)/length(unique(old))
#####################################################
##2. Now the same, but in the other dimension
#Turn into long format
wiot_long <- 
  wiot_ag_r %>% 
  select(-"TOT") %>% 
  pivot_longer(
    !c(Country,sup_sector_harm),
       names_to = "country_sector",
       values_to = "IO") %>% 
  mutate(imp_country = substr(country_sector,1,3),
         imp_sector = substr(country_sector,4,nchar(country_sector)),
         new_sector_long = dic_wiot_num_smallest[imp_sector])

##Now aggregate in similar way as in step 1.
wiot_ag_r_c <- wiot_long %>% 
  group_by(sup_sector_harm,
           Country,imp_country,new_sector_long) %>% 
  summarise(IO = sum(IO))

##Move back to wide format
wiot_ag <- wiot_ag_r_c %>% 
  ungroup() %>% 
  pivot_wider(names_from = c(imp_country,new_sector_long),
              values_from = IO) 

#Rough check, should be roughly row number of new df:
#print(dim(wiot)[1]*length(unique(new_smallest))/length(unique(old)) + 
#        length(country_names))

rm(wiot_ag_r,wiot_long,wiot_ag_r_c)
#####################################################
#Sort and clean 
#Start with columns
wiot_ag <- wiot_ag %>% 
  relocate(colnames(wiot_ag)[grepl("57$|58$|59$|60$|61$|
                                   final_use$|cap_form$|invent$",
                                   colnames(wiot_ag))],
           .after = last_col())

#Same for rows
wiot_ag <- wiot_ag %>% 
  mutate(sup_sector_harm = factor(sup_sector_harm,
                                  levels = (c(new_smallest_ordered,
                                                    "II_fob","TXSP",
                                                    "EXP_adj","PURR",
                                                    "PURNR","VA",
                                                    "IntTTM","GO")
                                ))) %>% 
  arrange(sup_sector_harm) %>% 
  mutate(sup_sector_harm = as.character.factor(sup_sector_harm))


###
#Check trade ratio on GDP
total_GDP <- wiot_ag %>% ungroup() %>% 
  filter(Country != "TOT") %>% 
  summarise(across(where(is.numeric), sum)) %>% 
  rowSums() 

diag_m <- wiot_ag %>% ungroup() %>% 
  filter(Country != "TOT") %>% 
  pivot_longer(-c(sup_sector_harm,Country),
               names_to = "country_sector",
               values_to = "Value") %>% 
  mutate(imp_country = substr(country_sector,1,3),
         sector = substr(country_sector,4,nchar(country_sector))) %>% 
  filter(imp_country==Country)

sum_diag <- diag_m %>% ungroup() %>% summarise(total = sum(Value))

(total_GDP - sum_diag)/total_GDP
###
dir.create("./data/manipulated/IO", showWarnings = F)
saveRDS(wiot_ag,"./data/manipulated/IO/wiod.rds")
#####################################################
####Create NT sector
#####################################################
wiot_ag_NT <- 
  wiot_ag %>% pivot_longer(
    !c(Country,sup_sector_harm),
    names_to = "country_sector",
    values_to = "IO") %>% 
  mutate(use_country = substr(country_sector,1,3),
         use_sector = substr(country_sector,5,nchar(country_sector)))

if (trade_NT == FALSE){
  ##Set all NTs to 0, where there is currently trade
  wiot_ag_NT <- wiot_ag_NT %>% 
    mutate(
      IO = replace(IO,
                    use_country != Country & 
                      (use_sector %in% non_traded_sectors | 
                         sup_sector_harm %in% non_traded_sectors) & 
                      sup_sector_harm != "GO" & 
                      sup_sector_harm != "VA",
                    0),
    )
}
         
##Now aggregate them all into one sector
wiot_ag_NT <- wiot_ag_NT %>% 
  mutate(use_sector = replace(use_sector,
                              use_sector %in% non_traded_sectors,
                              "NT"),
         sup_sector_harm = replace(sup_sector_harm,
                                   sup_sector_harm %in% non_traded_sectors,
                              "NT")) %>% 
  group_by(use_sector,sup_sector_harm,use_country,Country) %>% 
  summarise(IO = sum(IO)) %>% 
  pivot_wider(names_from = c(use_country,use_sector),
              values_from = IO) 
saveRDS(wiot_ag_NT,paste("./data/manipulated/IO/wiod_",
                         ending,
                         ".rds",
                         sep=""))
#####################################################
####Merge the emissions data
#####################################################
##Merge the same sector structure
list_emissions <- lapply(list_emissions,
                         function(df) {arrange(df,IndustryCode)}
                         )

for (country in names(list_emissions)){
  list_emissions[[country]]$sector = 
    dic_emi_smallest[list_emissions[[country]]$IndustryCode]
}


##Turn into one dataframe of same format as wiot data
df_emissions <- bind_rows(list_emissions) %>% 
  relocate(Country, .before = IndustryName)


df_emissions_merge <- df_emissions %>% 
  mutate(CH4_CO2_eq = CH4*28/1000000, #Convert into million tonnes
         N2O_CO2_eq = N2O*265/1000000,
         CO2_eq = CO2/1000+CH4_CO2_eq+N2O_CO2_eq) %>% ##CO2 is in GG, CH4 and N2O in t
  filter(!is.na(Country),!is.na(sector),
         sector != "TOT", sector != "total", sector != "FC_HH") %>% 
  ##Question EA: Maybe keep HH emissions as final_use?
  mutate(sector = replace(sector,
                          sector %in% non_traded_sectors,
                          "NT")) %>% 
  group_by(Country,sector) %>% 
  summarise(emissions = sum(CO2_eq, na.rm = TRUE)) %>% 
  pivot_wider(names_from = c(Country,sector),
              values_from = emissions) %>% 
  mutate(sup_sector_harm = "CO2") %>% 
  relocate(sup_sector_harm, .before = "AUS_A")


####
####

wiot_ag_NT_e <- wiot_ag_NT %>% 
  rbind(df_emissions_merge) %>% 
  mutate(Country = replace(
    Country,
    sup_sector_harm == "CO2",
    "TOT"
  ))


####
##Replace missing and 0s by EORA data
####
eora_co2 <- readRDS("./data/manipulated/IO/eora_aggregated_co2.rds") %>%  
  pivot_longer(-c(sup_sector_harm),
               names_to = "country_sector",
               values_to = "EORA_Value") %>% 
  mutate(use_country = substr(country_sector,1,3),
         use_sector = substr(country_sector,5,nchar(country_sector)),
          country_sector = NULL,
         sup_sector_harm = NULL)


wiot_ag_NT_e <- wiot_ag_NT_e %>% 
  pivot_longer(-c(sup_sector_harm,Country),
               names_to = "country_sector",
               values_to = "Value") %>% 
  mutate(use_country = substr(country_sector,1,3),
         use_sector = substr(country_sector,5,nchar(country_sector)),
         country_sector = NULL) %>% 
  left_join(eora_co2) %>% 
  mutate(Value = ifelse(sup_sector_harm == "CO2" & 
                           (is.na(Value) |
                             use_country %in% countries_eora_emissions),
                         EORA_Value,
                        Value),
         EORA_Value = NULL) %>% 
  pivot_wider(names_from = c(use_country,use_sector),
              values_from = Value)

#####
saveRDS(wiot_ag_NT_e,
        paste("./data/manipulated/IO/wiod_",
              ending,
              "_E.rds",sep=""))


#####################################################
####Create scope 2 emissions
#####################################################
### Allocate the NT emissions over the traded sectors
### Do this based on VA share in country
wiot_ag_NT_scope_2 <- wiot_ag_NT_e %>% 
  pivot_longer(
    !c(Country,sup_sector_harm),
    names_to = "country_sector",
    values_to = "Value") %>% 
  mutate(use_country = substr(country_sector,1,3),
         use_sector = substr(country_sector,5,nchar(country_sector))) %>% 
  # Add VA and CO2 as columns, easier to work with
  group_by(use_country,use_sector) %>% 
  mutate(VA = Value[sup_sector_harm == "VA"][1],
         direct_emi = Value[sup_sector_harm == "CO2"][1]) %>% 
  # Add NT emissions to be divided over others
  group_by(use_country) %>% 
  mutate(NT_emi = Value[sup_sector_harm == "CO2" & use_sector == "NT"][1]) %>% 
  # Create VA shares
  group_by(use_country,Country,sup_sector_harm) %>% 
  mutate(VA_tot = sum(VA), 
         VA_share = VA/VA_tot) %>% 
  ungroup() %>% 
  # Create indirect and scope 2 emissions
  mutate(indirect_emi = if_else(use_sector %in% trade_sectors,
                                VA_share * NT_emi,
                                if_else(
                                  use_sector == "NT",
                                  VA_share * NT_emi,
                                  NA_real_
                                )),
         scope_2_emi = if_else(use_sector %in% trade_sectors,
                               indirect_emi+direct_emi,
                               if_else(
                                 use_sector == "NT",
                                 indirect_emi+0,
                                 NA_real_
                               )
                               )
  ) %>% 
  select(-c(NT_emi,VA_tot,VA_share,country_sector,direct_emi,VA)) 

# Now extract the last two columns and turn them into other df
# to then rbind them at the bottom
to_bind <- wiot_ag_NT_scope_2 %>% 
  select(use_country,use_sector,indirect_emi,scope_2_emi) %>% 
  pivot_longer(c(indirect_emi,scope_2_emi),
               names_to = "sup_sector_harm",
               values_to = "Value") %>% 
  mutate(Country = "TOT") %>% 
  distinct()

wiot_ag_NT_scope_2 <- rbind(select(
  wiot_ag_NT_scope_2,-c(indirect_emi,scope_2_emi)),
  to_bind)%>% 
  pivot_wider(id_cols=c(Country,sup_sector_harm),
              names_from = c(use_country,use_sector),
              values_from = Value) %>% 
  filter(sup_sector_harm != "CO2", sup_sector_harm != "indirect_emi") %>% 
  mutate(sup_sector_harm = replace(
    sup_sector_harm,
    sup_sector_harm == "scope_2_emi",
    "CO2"
  ))

saveRDS(wiot_ag_NT_scope_2,paste(
  "./data/manipulated/IO/wiod_",
  ending,
  "_scope2.rds",sep=""))
#####################################################
####Add OECD tax revenue
#####################################################
df_tax_rev <- read.table("./data/raw/OECD/env_tax_rev/ERTR_31012023222956399.csv",
               sep = ",",
               header = TRUE) %>% 
  tibble() %>% 
  mutate(Country = NULL,
         use_sector = "A") %>% 
  rename(use_country = 1,
         sup_sector_harm = VAR,
         tax_rev = Value) %>% 
  filter(Variable == "Tax revenue, millions USD",
         Year == 2009,
         CAT == "TOT",
         DOM == "CC") %>% 
  select(use_country,tax_rev,sup_sector_harm,use_sector)

saveRDS(df_tax_rev,"./data/manipulated/tax_rev_ene_cc.rds")

###Replicate matrix and add a column for each sector.
##Needed for merging to IO table
df_tax_rev <- data.frame(df_tax_rev,
                         i=rep(1:(length(final_sectors)),
                               ea=NROW(df_tax_rev)))

for (i in 1:length(final_sectors)){
  df_tax_rev <- df_tax_rev %>% 
    mutate(use_sector = replace(use_sector,
                                i ==i,
                                final_sectors[i]))
}

df_tax_rev <- df_tax_rev %>% 
  mutate(sup_sector_harm = replace(
    sup_sector_harm,
    sup_sector_harm == "BASE_USD",
    "ENE_CC_tax_rev"
  )) %>% #Rename for merging to wiot
  rename(Value = tax_rev)

### Add to main DF
wiot_ag_NT_e_t <- wiot_ag_NT_e %>% 
  pivot_longer(!c(Country,sup_sector_harm),
              names_to = "country_sector",
              values_to = "Value") %>% 
      mutate(use_country = substr(country_sector,1,3),
             use_sector = substr(country_sector,5,13),
             country_sector = NULL) %>% 
      rbind(select(df_tax_rev,-i)) %>% 
  filter(use_country %in% unique(wiot_ag_NT_e$Country)) %>% 
  pivot_wider(names_from = c(use_country,use_sector),
              values_from = c(Value)) %>% 
  mutate(Country = replace(
    Country,
    sup_sector_harm == "ENE_CC_tax_rev",
    "TOT"
  ))

###
# Save
###
saveRDS(wiot_ag_NT_e_t,paste(
  "./data/manipulated/IO/wiod_",
  ending,
  "_E_T.rds",sep=""))
