###############
##### Purpose:
### File used to calculate energy costs per country and sector
### Use prices from IEA/OECD and emissions/energy use from WIOD and EORA
### Create for all WIOD and EORA countries, the aggregation does not happen here
###############
#################
##Start reading in EORA data, aggregated before
#################
source("./datamanipulation_scripts/manipulate/mappings/sector_mappings.R")
dic_emi_smallest <- setNames(new_emi_smallest,old_emi)

eora_Q <- readRDS("./data/manipulated/IO/eora_aggregated_Q.rds")
unique(eora_Q$GHG)
eora_energy <- eora_Q %>% 
  filter(GHG == "Energy Usage (TJ)") %>% 
  unique() %>% 
  pivot_longer(!c(GHG,sup_sector_harm),#,
               names_to = "country_sector",
               values_to = "Value") %>% 
  mutate(use_country = substr(country_sector,1,3),
         use_sector = substr(country_sector,5,nchar(country_sector)),
         country_sector = NULL) %>% 
  pivot_wider(names_from = sup_sector_harm,
              values_from = Value)
#################
##Read in all the Energy data from WIOD
#################
filenames <- list.files("./data/raw/WIOTS_in_R/EM",
                        pattern="*.xls",
                        full.names=TRUE)
country_names <- lapply(filenames,substr,start=26,stop=28)
suppressMessages(list_energy <- lapply(filenames, read_xls, sheet="2009"))
names(list_energy) <- country_names


for (i in 1:length(list_energy)){
  list_energy[[i]] <- list_energy[[i]] %>% 
    mutate(Country = (country_names[[i]][1]))
}

for (i in 1:length(list_energy)){
  colnames(list_energy[[i]])[1:2] <- c("IndustryName","IndustryCode")
}

list_energy <- lapply(list_energy,
                      function(df) {arrange(df,IndustryCode)}
)


for (country in names(list_energy)){
  list_energy[[country]]$sector = 
    dic_emi_smallest[list_energy[[country]]$IndustryCode]
}

wiod_energy <- bind_rows(list_energy) %>% 
  relocate(Country, .before = IndustryName) %>% ##All in TJ
  filter(IndustryCode != "total", !is.na(IndustryCode),
         IndustryCode != "FC_HH", IndustryCode != "secTOT")

########################
##Now turn into same format
##Pick common source structure
#names(eora_energy)
#names(wiod_energy)
wiod_energy_align <- wiod_energy %>% 
  mutate(renewable = WASTE+BIOGAS+BIODIESEL+BIOGASOL+GEOTHERM+HYDRO+NUCLEAR+
           WIND+SOLAR+OTHSOURC+OTHRENEW,
         WASTE = NULL,
         BIOGAS = NULL,
         BIODIESEL = NULL,
         BIOGASOL = NULL,
         coking_coal = HCOAL + COKE,
         steam_coal = BCOAL,
         HCOAL =NULL,
         BCOAL = NULL,
         COKE = NULL,
         nat_gas = NATGAS + OTHGAS,
         NATGAS = NULL,
         OTHGAS = NULL,
         nuclear = NUCLEAR,
         HYDRO = NULL,
         GEOTHERM = NULL,
         NUCLEAR = NULL,
         electricity = ELECTR +HEATPROD,
         diesel = DIESEL,
         gasoline = GASOLINE + JETFUEL,
         light_fuel_oil = LFO,
         heavy_fuel_oil = HFO,
         petroleum = CRUDE + NAPHTA + OTHPETRO) %>% 
  select(-c( CRUDE , DIESEL , GASOLINE , JETFUEL , LFO , HFO , NAPHTA , ELECTR,
             OTHPETRO,SOLAR,WIND,OTHSOURC,LOSS,TOTAL,IndustryName,OTHRENEW,
             HEATPROD,IndustryCode)) %>% 
  pivot_longer(!c(Country,sector),
               names_to = "source",
               values_to = "amount")

eora_energy_align <- eora_energy %>% 
  mutate(renewable = `Biomass and Waste Electricity` + `Geothermal Electricity`+
           `Hydroelectric Electricity` + `Solar, Tide and Wave Electricity`+
           `Wind Electricity`,
         coking_coal = 0.5*Coal,
         steam_coal = 0.5*Coal,
         nat_gas = `Natural Gas`,
         nuclear = `Nuclear Electricity`,
         light_fuel_oil = Petroleum) %>% 
  ungroup() %>% 
  select(-c(`Biomass and Waste Electricity`,`Geothermal Electricity`,
              `Hydroelectric Electricity`, `Solar, Tide and Wave Electricity`,
              `Wind Electricity`, Coal, `Natural Gas`,`Nuclear Electricity`,
              Petroleum,GHG)) %>% 
  rename(Country = use_country, sector = use_sector) %>% 
  pivot_longer(!c(Country,sector),
               names_to = "source",
               values_to = "amount")
# Add OECD average price 
df_oecd_price <- data.frame(
  source = c("petroleum",
             "heavy_fuel_oil",
             "light_fuel_oil",
             "diesel",
             "gasoline",
             "nat_gas",
             "steam_coal",
             "coking_coal",
             "electricity"),
  description = c("LSO (call petroleum)",
             "heavy_fuel_oil",
             "light_fuel_oil",
             "diesel",
             "gasoline",
             "natural Gas ",
             "steam coal (brown)",
             "coking coal (Hcoal and coke)",
             "electricity (electricity)"), #The descriptions are notes
  price_TOE = c(498,381.7,631.8,1111.4,918.3,383.0,151.7,223.1,1235.8) 
  #All in $/Toe; all taken from 2009 IEA prices
  ) %>% 
  mutate(price_TJ = 23.88458966275*price_TOE)
#1 Terajoules = 23.88458966275 Tonne Of Oil Equivalent

#######################################
##Determine country and sector specific costs
#######################################
df_e_cost_wiod <- wiod_energy_align %>% 
  left_join(df_oecd_price) %>% 
  mutate(cost = amount*price_TJ) %>% 
  group_by(Country,sector) %>% 
  summarise(e_cost = sum(cost,na.rm=T)) %>% 
  ungroup() %>% 
  mutate(e_cost = e_cost/1000000) %>%  #Turn into million dollar
  mutate(sector = replace(sector,
                          sector %in% non_traded_sectors,
                          "NT")) %>% 
  group_by(sector,Country) %>% 
  summarise(e_cost = sum(e_cost))


df_e_cost_eora <- eora_energy_align %>% 
  left_join(df_oecd_price) %>% 
  mutate(cost = amount*price_TJ) %>% 
  group_by(Country,sector) %>% 
  summarise(e_cost = sum(cost,na.rm=T)) %>% 
  ungroup() %>% 
  mutate(e_cost = e_cost/1000000) #Turn into million dollar

###############
#Replace 0s by minimum in sector
for (sector_run in unique(df_e_cost_eora$sector)){
  df_sector <- df_e_cost_eora %>% filter(sector == sector_run)
  
  min_non_negative <- min(df_sector$e_cost[df_sector$e_cost > 0])
  
  df_e_cost_eora <- df_e_cost_eora %>% 
    mutate(e_cost = replace(e_cost,
                             e_cost==0 & sector == sector_run,
                             min_non_negative))
}
###############
##Replace specified countries with EORA estimates in WIOD table
wiod_missing <- eora_energy_align %>% 
  filter(Country %in% countries_eora_emissions) %>% 
  left_join(df_oecd_price) %>% 
  mutate(cost = amount*price_TJ) %>% 
  group_by(Country,sector) %>% 
  summarise(e_cost = sum(cost,na.rm=T)) %>% 
  ungroup() %>% 
  mutate(e_cost = e_cost/1000000) #Turn into million dollar

df_e_cost_wiod <- df_e_cost_wiod %>% 
  filter(!(Country %in% countries_eora_emissions)) %>% 
  rbind(wiod_missing)
###############
saveRDS(df_e_cost_wiod,"./data/manipulated/IO/wiod_e_cost.rds")
saveRDS(df_e_cost_eora,"./data/manipulated/IO/eora_e_cost.rds")
