###############
##Purpose: Split WIOD RoW into EORA countries
#author: KS, 03.02.2023
###############
###############
#####
#### For saving files, based on choice of NT
if (trade_NT == FALSE){
  ending <- "NT"
} else{
  ending <- "other"
}

#################
##Start reading in manipulated IO data
#################

wiod <- readRDS(paste("./data/manipulated/IO/wiod_",
                      ending,
                      ".rds",
                      sep="")) %>% 
  select(-c(ends_with(c("invent","cap_form")))) 

eora <- readRDS("./data/manipulated/IO/eora_full.rds")

eora_VA <- readRDS("./data/manipulated/IO/eora_aggregated_VA.rds") %>% 
  filter(sup_sector_harm == "Consumption of fixed capital K.1" |
         sup_sector_harm == "Compensation of employees D.1") %>% 
  mutate(sup_sector_harm = if_else(sup_sector_harm == 
                                     "Consumption of fixed capital K.1",
                                   "capital",
                                   "labor")
  )
eora_GDP <- readRDS("./data/manipulated/IO/eora_aggregated_VA.rds")

wiod_e <- readRDS(paste("./data/manipulated/IO/wiod_",
                        ending,
                        "_E.rds",
                        sep="")) %>% 
  select(-c(ends_with(c("final_use","invent","cap_form"))))

eora_q <- readRDS("./data/manipulated/IO/eora_aggregated_co2.rds") 

#Load all the sector setting from different script
source("./datamanipulation_scripts/manipulate/mappings/sector_mappings.R")

###Needed for whole script
wiod_countries <- unique(wiod$Country) 

##################################
##First choose which countries to keep in EORA based on VA and cutoff 
##################################
eora_cutoff <- eora_GDP %>% 
  pivot_longer(-c(sup_sector_harm),
               names_to =  "country_sector",
               values_to = "Value") %>% 
  mutate(use_country = substr(country_sector,1,3),
         use_sector = substr(country_sector,5,nchar(country_sector))) %>% 
  pivot_wider(id_cols = c(use_country,use_sector),
              names_from = sup_sector_harm,
              values_from = Value) %>% 
  mutate(VA = rowSums(across(where(is.numeric)))) %>% 
  group_by(use_country) %>% 
  summarise(GDP = sum(VA)) %>% 
  filter(!(use_country %in% wiod_countries))

###
#Find the GDP cutoff and indicate which countries to keep
###
if (cutoff_choice == "n") {
  eora_amount <- cutoff_n-length(wiod_countries)+1
  GDP_cut <- sort(eora_cutoff$GDP,T)[eora_amount]
  ROW_countries <- filter(eora_cutoff,GDP<GDP_cut)$use_country
} else{
  ROW_countries <- filter(eora_cutoff,GDP<cutoff_va)$use_country
}
find_0s <- eora_q %>% 
  select(-sup_sector_harm) %>% 
  pivot_longer(everything(),
               names_to = "country_sector",
               values_to = "emissions"
  ) %>% 
  mutate(country = substr(country_sector,1,3),
         sector = substr(country_sector,4,nchar(country_sector))) %>% 
  group_by(country) %>% 
  summarise(tot_emissions = sum(emissions))

ROW_countries <- c(ROW_countries,filter(find_0s,tot_emissions==0)$country)

###Add countries with 0 emissions, as these are data errors:
##EORA mistake


###
#Dataframe where all countries that are too small are grouped into ROW
###
eora_ROW <- eora %>% 
  pivot_longer(-c(Country,sup_sector_harm),
                             names_to =  "country_sector",
                             values_to = "Value") %>% 
  mutate(use_country = substr(country_sector,1,3),
         use_sector = substr(country_sector,5,nchar(country_sector))) %>% 
  mutate(use_ROW_country = if_else(use_country %in% ROW_countries | 
                                     use_country =="ROW",
                                "ROW",
                               use_country),
         sup_ROW_country = if_else(Country %in% ROW_countries,
                                   "ROW",
                                   Country)) %>% 
  group_by(sup_ROW_country,sup_sector_harm,use_ROW_country,use_sector) %>% 
  summarise(Value = sum(Value)) %>% 
  pivot_wider(names_from = c(use_ROW_country,use_sector),
              values_from = Value) %>% 
  rename(Country = sup_ROW_country) %>% 
  filter(!is.na(Country)) #For total and VA 

rm(find_0s,eora_cutoff,eora_GDP,cutoff_n,cutoff_va)
##################################
##Then split the wiod ROW row and columns
##################################
###Do the splitting in two steps:
#First Split the rows then the columns
#For this first: aggregate in EORA the respectively other dimension
#into the same country split as in wiod, 
#and in the respective dimension we only keep the RoW countries.
#We then get the share of each cell entry on the other dimension total
#Use these shares to then split WIOD
######


####### Start with rows
### Need to do the shares calculation by sector, so for each sector 
### calculate total supply and then take share of each country on it


### Start: Turn EORA column dimension into same country dimension as wiod
eora_wiod_row <- eora_ROW %>% pivot_longer(-c(sup_sector_harm,Country),
                                           names_to =  "country_sector",
                                           values_to = "Value") %>% 
  mutate(use_country = substr(country_sector,1,3),
         use_sector = substr(country_sector,5,nchar(country_sector))) %>% 
  #Turn into same column dimension as in wiod
  mutate(wiod_country = if_else(use_country %in% wiod_countries,
                                use_country,
                                "ROW")) %>% 
  group_by(sup_sector_harm,Country,use_sector,wiod_country) %>% 
  summarise(Value = sum(Value)) %>% 
  pivot_wider(names_from = c(wiod_country,use_sector),
              values_from = Value) %>% 
  #Drop countries in wiod from row dimension
  filter(!(Country %in% wiod_countries) | 
           (Country == "ROW" & sup_sector_harm != "TOT"))

## Now loop through all the sectors (Would also work with apply)
eora_shares_row <- data.frame(matrix(NA,
                                     nrow = dim(eora_wiod_row)[1],
                                     ncol = dim(eora_wiod_row)[2]
)
)

i <- 1

for (sector in unique(eora_ROW$sup_sector_harm)){
  eora_run <- eora_wiod_row %>% 
    filter(sup_sector_harm == sector) %>% 
    ungroup() %>% 
    #Sum each column and add row at bottom
    janitor::adorn_totals(fill = "Total")
  
    eora_shares_row[i:(i+(dim(eora_run)[1]-2)),] <- eora_run %>% 
      mutate_if(is.numeric, ~ . / last(.)) %>% 
      filter(Country != "Total") #Was only used for division
    
    i <- i+dim(eora_run)[1]-1
}
colnames(eora_shares_row) <- colnames(eora_wiod_row)

####
##Pick the wiod part that will be split
wiod_row <- wiod %>% 
  filter(Country == "ROW") 

##Before multiplying matrices make sure order is correct
if (identical(colnames(filter(wiod,Country == "ROW")),
              colnames(eora_wiod_row)) == 
    FALSE) {
  print("ALARM")
  stop("wiod df and eora df have different order. Muliplication will be wrong")
}
##################
###Now split the wiod table into the individual countries
##Multiply the respective country share by the total wiod ROW value
##################
new_rows <- data.frame(matrix(NA,
                              nrow = dim(eora_shares_row)[1],
                              ncol = dim(wiod_row)[2]
                       )
              )

i <- 1

for (country in unique(eora_shares_row$Country)){
  eora_short <- eora_shares_row %>% 
    filter(Country == country)
  
  df_run <- eora_short %>% keep(is.numeric) * 
    wiod_row %>% keep(is.numeric) # Multiply EORA share with wiod value
  
  df_run <- cbind(eora_short[,1:2],df_run) #Just add Country and sector column

  new_rows[i:(i+dim(df_run)[1]-1),] <- df_run #Add to final DF
  
  i <- i+dim(df_run)[1]
  
}

colnames(new_rows) <- colnames(eora_short)

######
###Now replace original ROW in wiod with this
######

wiod_new_rows <- wiod %>% 
  filter(Country != "ROW") %>% 
  rbind(new_rows) %>% 
  arrange(sup_sector_harm,Country) ##Important so we can copy column names below


######
#Check
new <- new_rows %>% ungroup() %>% 
  janitor::adorn_totals(fill = "Old_RoW") %>% 
  filter(Country=="Old_RoW")
new_sum <- sum(select(new,(where(is.numeric))))
new_example <- new_rows %>% ungroup() %>% 
  filter(sup_sector_harm == "NT") %>% 
  janitor::adorn_totals(fill = "Old_RoW") %>% 
  filter(Country=="Old_RoW") %>% 
  select(`CHN_C10-C12`)

old <- (filter(ungroup(wiod),Country=="ROW"))
old_sum <- sum(select(old,where(is.numeric)))
old_example <- select(filter(old,sup_sector_harm == "NT"),`CHN_C10-C12`)
  
  
if (round(new_sum,3) != round(old_sum,3)) {
  print("ALARM")
  stop("New values do not sum to old ROW value")
}

if (round(new_example,3) != round(old_example,3))  {
  print("ALARM")
  stop("New values do not sum to old ROW value")
}

######
rm(list = c("df_run","eora_run","eora_short","new_rows","wiod_row",
            "new","old","new_example","old_example","new_sum","old_sum"))

#######################################
##Now other dimension
#######################################
#Turn EORA row dimension into same country dimension as wiod 
eora_wiod_col <- eora_ROW %>% pivot_longer(-c(sup_sector_harm,Country),
                                              names_to =  "country_sector",
                                              values_to = "Value") %>% 
  mutate(use_country = substr(country_sector,1,3),
         use_sector = substr(country_sector,5,nchar(country_sector))) %>% 
  #Drop columns with wiod countries
  filter(!(use_country %in% wiod_countries) | 
           use_country == "ROW",
         !(Country == "ROW" & sup_sector_harm == "TOT")) %>%
  select(-country_sector) %>% 
  ##Important so we can copy column names below
  arrange(sup_sector_harm,Country,use_sector) %>% 
  pivot_wider(names_from = c(use_country,use_sector),
              values_from = Value) 

#######
eora_shares_col <- data.frame(matrix(NA,
                                       nrow = dim(eora_wiod_col)[1],
                                       ncol = dim(eora_wiod_col)[2]-2
  )
  )

i <- 1

## Add column with total on right for each sector individually
## And likewise get then the share by dividing through it
for (sector in final_use_sectors){
  eora_shares_col_run <- eora_wiod_col %>% 
    ungroup() %>% 
    select(ends_with(sector)) %>% 
    mutate(total = rowSums(across(where(is.numeric)))) 
  
  #Then divide everything by it to get the shares again
  eora_shares_col[,i:(i+(dim(eora_shares_col_run)[2]-2))] <-  
    eora_shares_col_run %>% 
      ungroup() %>% 
      mutate(across(where(is.numeric),~.x/total)) %>% 
      select(-c(total))
  
  i <- i+dim(eora_shares_col_run)[2]-1 #-1 because of the total column
}
####
##Add country and sector columns, and column names
eora_shares_col <- cbind(filter(eora_wiod_col,Country != "TOT")[,1:2],
                         eora_shares_col)
colnames(eora_shares_col) <- colnames(eora_wiod_col)  

eora_shares_col <- eora_shares_col %>% 
  #Just to arrange
  pivot_longer(-c(sup_sector_harm,Country),
               names_to =  "country_sector",
               values_to = "Value") %>% 
  mutate(use_country = substr(country_sector,1,3),
         use_sector = substr(country_sector,5,nchar(country_sector))) %>% 
  select(-country_sector) %>% 
  ##Important so we can copy column names below
  arrange(sup_sector_harm,Country,use_country) %>% 
  pivot_wider(names_from = c(use_country,use_sector),
              values_from = Value) 

######
#Now pick the wiod columns to be split
#Base on the new wiod df already
######
wiod_col <- wiod_new_rows %>% 
  ungroup() %>% 
  filter(Country != "TOT") %>% 
  select(starts_with("ROW"))

#########
##Add some checks
if (identical((filter(wiod_new_rows,Country != "TOT")$Country),
              (eora_shares_col)$Country) == 
    FALSE) {
  print("ALARM")
  stop("Order in dfs does not align")
}

if (identical((filter(wiod_new_rows,Country != "TOT")$sup_sector_harm),
              as.character((eora_shares_col)$sup_sector_harm)) == 
    FALSE) {
  print("ALARM")
  stop("Order in dfs does not align")
}
##########
###And now going through 
######
new_cols <- data.frame(matrix(NA,
                              nrow = dim(wiod_col)[1],
                              ncol = (dim(eora_shares_col)[2]-2)
)
)

i <- 1
for (country in unique(eora_shares_row$Country)){
  eora_short <- eora_shares_col %>% 
    ungroup() %>% 
    select(starts_with(country)) 
  #Element wise multiplication
  df_run <- eora_short * wiod_col 

  new_cols[,i:(i+dim(df_run)[2]-1)] <- df_run
  i <- i+dim(df_run)[2]
}
#Add country and sector column
new_cols <- cbind(filter(eora_shares_col,Country != "TOT")[,1:2],new_cols)

colnames(new_cols) <- colnames(eora_shares_col) 

######
###Bring it together
######
wiod_new <- wiod_new_rows %>% 
  filter(Country != "TOT") %>% 
  select(!c(starts_with("ROW"))) %>% 
  left_join(new_cols, 
            by =c("Country","sup_sector_harm")) %>% 
  ###Now just to arrange 
  pivot_longer(-c(Country,sup_sector_harm),
               names_to =  "country_sector",
               values_to = "Value") %>% 
  mutate(use_country = substr(country_sector,1,3),
         use_sector = substr(country_sector,5,nchar(country_sector)),
         country_sector = NULL) %>% 
  arrange(use_country) %>% 
  pivot_wider(id_cols = c(Country,sup_sector_harm),
                names_from = c(use_country,use_sector),
              values_from = Value) %>% 
  arrange(Country)

############
#Check trade ratio on GDP
# total_GDP <- wiod_new %>% ungroup() %>% 
#   summarise(across(where(is.numeric), sum)) %>% 
#   rowSums() 
# 
# diag_m <- wiod_new %>% ungroup() %>% 
#   pivot_longer(-c(sup_sector_harm,Country),
#                names_to = "country_sector",
#                values_to = "Value") %>% 
#   mutate(imp_country = substr(country_sector,1,3),
#          sector = substr(country_sector,4,nchar(country_sector))) %>% 
#   filter(imp_country==Country)
# 
# sum_diag <- diag_m %>% ungroup() %>% summarise(total = sum(Value))
# 
# (total_GDP - sum_diag)/total_GDP

############
#Check
new <- new_cols %>% ungroup() %>% 
  mutate(ROW_old = rowSums(across(where(is.numeric)))) %>% 
  select(Country,sup_sector_harm,ROW_old)
new_sum <- sum(select(new,ROW_old))

new_example <-  new_cols %>% select(ends_with("NT")) %>% 
  filter(Country == "CHN",sup_sector_harm == "C10-C12") %>% 
  mutate(ROW_old = rowSums(across(where(is.numeric)))) %>% 
  select(Country,sup_sector_harm,ROW_old)
new_example <- sum(select(ungroup(new_example),ROW_old))
  
old <- (select(filter(ungroup(wiod_new_rows),Country!="TOT"),starts_with("ROW")))
old_sum <- sum(select(old,where(is.numeric)))
old_example <- rowSums(select(filter(ungroup(wiod),
                      Country=="CHN",sup_sector_harm=="C10-C12"),
               starts_with("ROW_NT")))

if (round(old_sum,3) != round(new_sum,3)) {
  print("ALARM")
  stop("New values do not sum to old ROW value")
}

if (round(new_example,3) != round(old_example,3))  {
  print("ALARM")
  stop("New values do not sum to old ROW value")
}

######
rm(list = c("df_run","eora_shares_col_run","eora_short","new_cols",
            "eora_shares_col","new","old","new_example","old_example","total_GDP",
            "diag_m","sum_diag"))

############  

####################################
###Need to set NTs to zero if chosen
####################################
wiod_new_NT <- wiod_new %>% 
  pivot_longer(
  !c(Country,sup_sector_harm),
  names_to = "country_sector",
  values_to = "IO") %>% 
  mutate(use_country = substr(country_sector,1,3),
         use_sector = substr(country_sector,5,nchar(country_sector)))

         ##Set all NTs to 0, where there is currently trade if chosen to do so
if (trade_NT == FALSE){
  wiod_new_NT <- wiod_new_NT %>% 
    mutate(
      IO = replace(IO,
                   use_country != Country & 
                     (use_sector == "NT" | 
                        sup_sector_harm == "NT"),
                   0),
    )
}

wiod_new_NT <- wiod_new_NT %>% 
  mutate(country_sector = NULL) %>% 
  pivot_wider(names_from = c(use_country,use_sector),
              values_from = IO) 

###
saveRDS(wiod_new_NT,
        paste("./data/manipulated/IO/",save_name,
                         ending,
                         ".rds",sep=""))

####################################
###Now emissions
####################################
#Pick the ones that are in RoW
eora_q_col <- eora_q %>% pivot_longer(-c(sup_sector_harm),
                                         names_to =  "country_sector",
                                         values_to = "Value") %>% 
  mutate(use_country = substr(country_sector,1,3),
         use_sector = substr(country_sector,5,nchar(country_sector))) %>% 
  filter(!(use_country %in% wiod_countries)) %>%
 #Now merge all too small into RoW
  mutate(use_ROW_country = if_else(use_country %in% ROW_countries | 
                                     use_country =="ROW",
                                   "ROW",
                                   use_country)) %>% 
  group_by(sup_sector_harm,use_ROW_country,use_sector) %>% 
  summarise(Value = sum(Value)) %>% 
  arrange(use_sector,use_ROW_country) %>% 
  mutate(country_sector = NULL) %>% 
  pivot_wider(names_from = c(use_ROW_country,use_sector),
              values_from = Value) 
  
#######
eora_shares_q <- data.frame(matrix(NA,
                                     nrow = dim(eora_q_col)[1],
                                     ncol = dim(eora_q_col)[2]-2
)
)

i <- 1
## Add column with total on right for each sector individually
## And likewise get then the share by dividing through it
for (sector in final_sectors){
  eora_shares_q_run <- eora_q_col %>% 
    ungroup() %>% 
    select(ends_with(sector)) %>% 
    rowwise() %>% 
    ##Add column with total on right
    #Then divide everything by it to get the shares again
    mutate(total = sum(c_across(where(is.numeric))))
  
  eora_shares_q[,i:(i+(dim(eora_shares_q_run)[2]-2))] <- eora_shares_q_run %>% 
    mutate(across(where(is.numeric),~.x/total)) %>% 
    ungroup() %>% 
    select(-total)
  
  i <- i+dim(eora_shares_q_run)[2]-1
}

eora_shares_q <- eora_shares_q %>% 
  mutate(sup_sector_harm = "CO2" , .before = everything())
colnames(eora_shares_q) <- colnames(eora_q_col)

eora_shares_q <- eora_shares_q %>% 
  #Just to arrange
  pivot_longer(-c(sup_sector_harm),
               names_to =  "country_sector",
               values_to = "Value") %>% 
  mutate(use_country = substr(country_sector,1,3),
         use_sector = substr(country_sector,5,nchar(country_sector))) %>% 
  select(-country_sector) %>% 
  ##Important so we can copy column names below
  arrange(use_country) %>% 
  pivot_wider(names_from = c(use_country,use_sector),
              values_from = Value) 

###
#Now pick the wiod columns to be split
wiod_col <- wiod_e %>% 
  ungroup() %>% 
  filter(sup_sector_harm == "CO2") %>% 
  select(starts_with("ROW"))

###And now going through 
new_cols <- data.frame(matrix(NA,
                              nrow = 1,
                              ncol = dim(eora_shares_q)[2]-1))

i <- 1
for (country in unique(eora_shares_row$Country)){
  eora_short <- eora_shares_q %>% 
    select(starts_with(country)) 
  #Element wise multiplication
  df_run <- eora_short %>% keep(is.numeric) * 
    wiod_col %>% keep(is.numeric)
  
  new_cols[,i:(i+dim(df_run)[2]-1)] <- df_run
  i <- i+dim(df_run)[2]
}

##No need for Country and sector column, add below
colnames(new_cols) <- colnames(eora_shares_q %>% 
                                 select(-sup_sector_harm))

###Bring it together
#First merge with the wiod row itself
#Then add the whole row at bottom of new wiod table
to_merge <- wiod_e %>% 
  filter(sup_sector_harm == "CO2") %>% 
  select(-starts_with("ROW"))
new_emissions <- cbind(to_merge,new_cols)
wiod_e_new <- rbind(wiod_new_NT,new_emissions) %>% 
  mutate(Country = replace(Country,
                           sup_sector_harm == "CO2",
                           "TOT")
         )

###
#Test
old <- filter(wiod_e,sup_sector_harm=="CO2")  %>% ungroup() %>% 
  select(starts_with("ROW")) %>% sum()
new <- new_cols %>% mutate(ROW_old = rowSums(across(where(is.numeric)))) %>% 
  select(ROW_old)

old==new
#############
#Add VA
#############
eora_VA_col <- eora_VA %>% pivot_longer(-c(sup_sector_harm),
                         names_to =  "country_sector",
                         values_to = "Value") %>% 
  mutate(use_country = substr(country_sector,1,3),
         use_sector = substr(country_sector,5,nchar(country_sector))) %>% 
  pivot_wider(id_cols = c(use_country,use_sector),
              names_from = sup_sector_harm,
              values_from = Value) %>% 
  mutate(VA = capital + labor) %>% 
  filter(!(use_country %in% wiod_countries)) %>%
  mutate(use_ROW_country = if_else(use_country %in% ROW_countries | 
                                     use_country =="ROW",
                                   "ROW",
                                   use_country)) %>% 
  group_by(use_ROW_country,use_sector) %>% 
  summarise(VA = sum(VA))  %>% 
  arrange(use_sector) %>% 
  pivot_wider(names_from = c(use_ROW_country,use_sector),
              values_from = VA) %>% 
  mutate(Country = "TOT",
         sup_sector_harm = "VA",
         .before = everything()) %>% 
  select(-ends_with("TOT")) 


eora_shares_VA <- data.frame(matrix(NA,
                                  nrow = dim(eora_VA_col)[1],
                                  ncol = dim(eora_VA_col)[2]-2
)
)

i <- 1
## Add column with total on right for each sector individually
## And likewise get then the share by dividing through it
for (sector in final_sectors){
  eora_shares_VA_run <- eora_VA_col %>% 
    ungroup() %>% 
    select(ends_with(sector)) %>% 
    rowwise() %>% 
  ##Add column with total on right
  #Then divide everything by it to get the shares again
  mutate(total = sum(c_across(where(is.numeric)))) 
  
  eora_shares_VA[,i:(i+(dim(eora_shares_VA_run)[2]-2))] <- eora_shares_VA_run %>% 
    mutate(across(where(is.numeric),~.x/total)) %>% 
    ungroup() %>% 
    select(-total)
  
  i <- i+dim(eora_shares_VA_run)[2]-1
}

eora_shares_VA <- eora_shares_VA %>% 
  mutate(Country = "TOT",
         sup_sector_harm = "VA" , 
         .before = everything())

colnames(eora_shares_VA) <- colnames(eora_VA_col)

eora_shares_VA <- eora_shares_VA %>% 
  #Just to arrange
  pivot_longer(-c(Country,sup_sector_harm),
               names_to =  "country_sector",
               values_to = "Value") %>% 
  mutate(use_country = substr(country_sector,1,3),
         use_sector = substr(country_sector,5,nchar(country_sector))) %>% 
  select(-country_sector) %>% 
  ##Important so we can copy column names below
  arrange(use_country) %>% 
  pivot_wider(names_from = c(use_country,use_sector),
              values_from = Value) 

###
#Now pick the wiod columns to be split
wiod_col <- wiod_e %>% 
  ungroup() %>% 
  filter(sup_sector_harm == "VA") %>% 
  select(starts_with("ROW"))

###And now going through 
new_cols <- data.frame(matrix(NA,
                              nrow = 1,
                              ncol = dim(eora_shares_VA)[2]-2))

i <- 1
for (country in unique(eora_shares_row$Country)){
  eora_short <- eora_shares_VA %>% 
    select(starts_with(country)) 
  #Element wise multiplication
  df_run <- eora_short %>% keep(is.numeric) * 
    wiod_col %>% keep(is.numeric)
  
  new_cols[,i:(i+dim(df_run)[2]-1)] <- df_run
  i <- i+dim(df_run)[2]
}
 
colnames(new_cols) <- colnames(eora_shares_VA %>% 
                                 select(!starts_with("total"),
                                        -sup_sector_harm,-Country))
###
#Test
old <- filter(wiod,sup_sector_harm=="VA")  %>% 
  ungroup() %>% 
  select(starts_with("ROW")) %>% 
  sum()
new <- new_cols %>% mutate(ROW_old = rowSums(across(where(is.numeric)))) %>% 
  select(ROW_old)

old==new

###Bring it together
#First merge with the wiod row itself
#Then add the whole row at bottom of new wiod table
to_merge <- wiod %>% filter(sup_sector_harm == "VA") %>% 
  select(-starts_with("ROW"))
new_VA <- cbind(to_merge,new_cols)
wiod_new_e_va <- rbind(wiod_e_new,new_VA) 

###############
saveRDS(wiod_new_e_va,
        paste("./data/manipulated/IO/",
              save_name,
              ending,
              "_E.rds",sep=""))


#####################################################
####Create scope 2 emissions
#####################################################
### Allocate the NT emissions over the traded sectors
### Do this based on VA share in country
wiod_new_e_va_scope_2 <- wiod_new_e_va %>% 
  pivot_longer(
    !c(Country,sup_sector_harm),
    names_to = "country_sector",
    values_to = "Value") %>% 
  mutate(use_country = substr(country_sector,1,3),
         use_sector = substr(country_sector,5,nchar(country_sector))) %>% 
  # Add VA and CO2 as columns, easier to work with
  group_by(use_country,use_sector) %>% 
  mutate(VA = Value[sup_sector_harm == "VA"][1],
         direct_emi = Value[sup_sector_harm == "CO2"][1]) %>% 
  # Add NT emissions to be divided over others
  group_by(use_country) %>% 
  mutate(NT_emi = Value[sup_sector_harm == "CO2" & use_sector == "NT"][1]) %>% 
  # Create VA shares
  group_by(use_country,Country,sup_sector_harm) %>% 
  mutate(VA_tot = sum(VA,na.rm=T), 
         VA_share = VA/VA_tot) %>% 
  ungroup() %>% 
  # Create indirect and scope 2 emissions
  mutate(indirect_emi = if_else(use_sector %in% trade_sectors,
                                VA_share * NT_emi,
                                if_else(
                                  use_sector == "NT",
                                  VA_share * NT_emi,
                                  NA_real_
                                )),
         scope_2_emi = if_else(use_sector %in% trade_sectors,
                               indirect_emi+direct_emi,
                               if_else(
                                 use_sector == "NT",
                                 indirect_emi+0,
                                 NA_real_
                               )
         )
  ) %>% 
  select(-c(NT_emi,VA_tot,VA_share,country_sector,direct_emi,VA)) 

# Now extract the last two columns and turn them into other df
# to then rbind them at the bottom
to_bind <- wiod_new_e_va_scope_2 %>% 
  select(use_country,use_sector,indirect_emi,scope_2_emi) %>% 
  pivot_longer(c(indirect_emi,scope_2_emi),
               names_to = "sup_sector_harm",
               values_to = "Value") %>% 
  mutate(Country = "TOT") %>% 
  distinct()

wiod_new_e_va_scope_2 <- rbind(select(
  wiod_new_e_va_scope_2,-c(indirect_emi,scope_2_emi)),
  to_bind)%>% 
  pivot_wider(id_cols=c(Country,sup_sector_harm),
              names_from = c(use_country,use_sector),
              values_from = Value) %>% 
  filter(sup_sector_harm != "CO2", sup_sector_harm != "indirect_emi") %>% 
  mutate(sup_sector_harm = replace(
    sup_sector_harm,
    sup_sector_harm == "scope_2_emi",
    "CO2"
  ))

saveRDS(wiod_new_e_va_scope_2,paste(
  "./data/manipulated/IO/",
  save_name,
  ending,
  "_scope2.rds",sep=""))


#####################################################
####Add OECD tax revenue
#####################################################
df_tax_rev <- read.table("./data/raw/OECD/env_tax_rev/ERTR_31012023222956399.csv",
                         sep = ",",
                         header = TRUE) %>% 
  tibble() %>% 
  mutate(Country = "TOT",
         use_sector = "A",
         Value = as.numeric(Value)) %>% 
  rename(use_country = 1,
         sup_sector_harm = VAR) %>% 
  filter(Variable == "Tax revenue, millions USD",
         Year == 2009,
         CAT == "TOT",
         DOM == "CC") %>% 
  select(use_country,Value,sup_sector_harm,use_sector,Country)

###Replicate matrix and add a column for each sector.
##Needed for merging to IO table
df_tax_rev <- data.frame(df_tax_rev,
                         i=rep(1:(length(final_sectors)),
                               ea=NROW(df_tax_rev)))

for (i in 1:length(final_sectors)){
  df_tax_rev <- df_tax_rev %>% 
    mutate(use_sector = replace(use_sector,
                                i ==i,
                                final_sectors[i]))
}

wiod_new_e_va_t <- wiod_new_e_va %>% 
  ungroup() %>% 
  pivot_longer(!c(Country,sup_sector_harm),
               names_to = "country_sector",
               values_to = "Value") %>% 
  mutate(use_country = substr(country_sector,1,3),
         use_sector = substr(country_sector,5,nchar(country_sector)),
         country_sector = NULL) %>% 
  add_row(select(df_tax_rev,-i)) %>% 
  filter(use_country %in% unique(wiod_new_e_va$Country)) %>% 
  pivot_wider(names_from = c(use_country,use_sector),
              values_from = c(Value)) %>% 
  mutate(sup_sector_harm = replace(sup_sector_harm,
                                   sup_sector_harm == "BASE_USD",
                                   "ENE_CC_tax_rev"))

saveRDS(wiod_new_e_va_t,
        paste("./data/manipulated/IO/",
              save_name,
              ending,
              "_E_T.rds",sep=""))

#####################
##E costs
#####################
##Read in data from e_price_calculation
df_e_cost_eora <- readRDS("./data/manipulated/IO/eora_e_cost.rds") %>% 
  filter(!Country %in% wiod_countries) %>%   #Drop all WIOT countries
  mutate(ROW_country = if_else(Country %in% ROW_countries | 
                                     Country == "ROW",
                                   "ROW",
                                   Country)) %>% 
    group_by(ROW_country,sector) %>% 
    summarise(e_cost = sum(e_cost)) %>% 
  ####Quite a lot of 0s in the remaining countries
  rename(Country = ROW_country)

df_e_cost_wiod <- readRDS("./data/manipulated/IO/wiod_e_cost.rds") 
df_e_cost_wiod_row <- df_e_cost_wiod %>%
  filter(Country == "ROW") %>% ungroup() %>% 
  rename(e_cost_wiot_row = e_cost)
  
df_sector_total <- df_e_cost_eora %>% 
  group_by(sector) %>% 
  summarise(sector_total = sum(e_cost))

df_e_cost_eora <- df_e_cost_eora %>% 
  left_join(df_sector_total) %>% 
  mutate(country_share = e_cost/sector_total) %>% 
  left_join(select(df_e_cost_wiod_row,-Country)) %>% 
  mutate(e_cost = e_cost_wiot_row*country_share) %>% 
  select(Country,sector,e_cost)

df_e_cost <- df_e_cost_wiod %>% 
  filter(Country != "ROW") %>% 
  rbind(df_e_cost_eora) %>% 
  arrange(Country,sector) %>% 
  relocate(Country,.before = sector)


saveRDS(df_e_cost,
        paste("./data/manipulated/IO/e_cost",
              save_name,
              ending,
              ".rds",sep=""))
